@@ -1,18 +1,18 @@
-/* 
- * Copyright (C) 2000-2019 the xine project
- * 
+/*
+ * Copyright (C) 2000-2021 the xine project
+ *
  * This file is part of xine, a unix video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
@@ -21,27 +21,14 @@
 #ifndef _COMMON_UTILS_H
 #define _COMMON_UTILS_H
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
+#ifndef HAVE_CONFIG_H
+#error config.h not included
 #endif
 
 #include <stdio.h>
 #include <stdarg.h>
 #include <sys/time.h>
 
-/* sys/time.h does not define timersub() on all platforms... */
-#ifndef timersub
-# define timersub(a, b, result)                                               \
-  do {                                                                        \
-    (result)->tv_sec = (a)->tv_sec - (b)->tv_sec;                             \
-    (result)->tv_usec = (a)->tv_usec - (b)->tv_usec;                          \
-    if ((result)->tv_usec < 0) {                                              \
-      --(result)->tv_sec;                                                     \
-      (result)->tv_usec += 1000000;                                           \
-    }                                                                         \
-  } while (0)
-#endif
-
 #ifndef NAME_MAX
 #define _NAME_MAX          256
 #else
@@ -60,9 +47,9 @@
 int xine_system(int dont_run_as_root, const char *command);
 
 /*
- * cleanup the str string, take care about '
+ * trim/reduce quoting and whitespace, return new strlen ().
  */
-char *atoa(char *str);
+size_t str_unquote (char *str);
 
 /*
  * Create directories recursively
@@ -87,7 +74,7 @@ size_t strlcat(char *dst, const char *src, size_t size);
 #endif
 
 #ifndef HAVE_STRLCPY
-size_t strlcpy(char *dst, const char *src, size_t size);
+size_t strlcpy (char *dst, const char *src, size_t size) ATTR_INLINE_ALL_STRINGOPS;
 #endif
 
 char *xitk_vasprintf(const char *fmt, va_list ap)  __attribute__ ((format (printf, 1, 0)));
