@@ -3,7 +3,9 @@
 #endif
 
 #include "Imlib.h"
+#include "Imlib_types.h"
 #include "Imlib_private.h"
+
 #include <locale.h>
 #include <stdio.h>
 #include "libcommon.h"
@@ -64,6 +66,28 @@ Imlib_set_render_type(ImlibData * id, int rend_type)
     }
 }
 
+void Imlib_destroy(ImlibData **p)
+{
+  ImlibData *id = *p;
+
+  if (!id)
+    return;
+  *p = NULL;
+
+  clean_caches(id);
+
+  free(id->palette);
+  free(id->palette_orig);
+  free(id->fast_rgb);
+  free(id->fast_err);
+  free(id->fast_erg);
+  free(id->fast_erb);
+
+  // XXX probably not complete ...
+
+  free(id);
+}
+
 #ifdef HAVE_SHM
 int
                     XShmGetEventBase(Display * disp);
@@ -376,7 +400,7 @@ Imlib_init(Display * disp)
     }
   setlocale(LC_NUMERIC, old_locale);
   free(old_locale);
-  
+
   /* list all visuals for the default screen */
   xvi.screen = id->x.screen;
   xvir = XGetVisualInfo(disp, VisualScreenMask, &xvi, &num);
@@ -437,7 +461,7 @@ Imlib_init(Display * disp)
 		{
 		  if (xvir[i].depth == id->x.depth)
 		    {
-		      if ((xvir[i].class > clas) && 
+		      if ((xvir[i].class > clas) &&
 			  (xvir[i].class != DirectColor))
 			{
 			  maxn = i;
@@ -757,7 +781,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
       f = fopen(__XOS2RedirRoot(SYSTEM_IMRC), "rt");
 #endif
     }
-  
+
   if (f)
     {
       size_t length;
@@ -932,7 +956,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
     }
   setlocale(LC_NUMERIC, old_locale);
   free(old_locale);
-  
+
   if (p)
     {
       if (p->flags & PARAMS_VISUALID)
@@ -1229,7 +1253,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
 }
 
 Pixmap
-Imlib_copy_image(ImlibData * id, ImlibImage * im)
+Imlib_copy_image(ImlibData * id, const ImlibImage * im)
 {
   Pixmap              p;
   GC                  tgc;
@@ -1258,7 +1282,7 @@ Imlib_move_image(ImlibData * id, ImlibImage * im)
 }
 
 Pixmap
-Imlib_copy_mask(ImlibData * id, ImlibImage * im)
+Imlib_copy_mask(ImlibData * id, const ImlibImage * im)
 {
   Pixmap              p;
   GC                  tgc;
@@ -1359,31 +1383,6 @@ Imlib_get_image_border(ImlibData * id, ImlibImage * im, ImlibBorder * border)
     }
 }
 
-void
-Imlib_get_image_shape(ImlibData * id, ImlibImage * im, ImlibColor * color)
-{
-  if ((!im) || (!color))
-    return;
-
-  color->r = im->shape_color.r;
-  color->g = im->shape_color.g;
-  color->b = im->shape_color.b;
-}
-
-void
-Imlib_set_image_shape(ImlibData * id, ImlibImage * im, ImlibColor * color)
-{
-  if ((!im) || (!color))
-    return;
-  if ((im->shape_color.r != color->r) || (im->shape_color.g != color->g) || (im->shape_color.b != color->b))
-    {
-      im->shape_color.r = color->r;
-      im->shape_color.g = color->g;
-      im->shape_color.b = color->b;
-      dirty_pixmaps(id, im);
-    }
-}
-
 int
 Imlib_get_fallback(ImlibData * id)
 {
