@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 2000-2019 the xine project
- * 
+ * Copyright (C) 2000-2021 the xine project
+ *
  * This file is part of xine, a unix video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
@@ -22,68 +22,52 @@
 #ifndef __COMMON_H__
 #define __COMMON_H__
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
+#ifndef PACKAGE_NAME
+#error config.h not included
 #endif
 
 #include <stdio.h>
 
 #include <xine.h>
 #include <xine/xineutils.h>
-
-#include "Imlib-light/Imlib.h"
+#include <xine/sorted_array.h>
 
 typedef struct gGui_st gGui_t;
 
 #include "xitk.h"
 
-#include "kbindings.h"
-#include "videowin.h"
-#include "mediamark.h"
-#include "actions.h"
+typedef struct xui_keyedit_s xui_keyedit_t;
+typedef struct xui_vwin_st xui_vwin_t;
+typedef struct xui_actrl_st xui_actrl_t;
+typedef struct xui_vctrl_st xui_vctrl_t;
+typedef struct xui_event_sender_st xui_event_sender_t;
+typedef struct xui_help_s xui_help_t;
+typedef struct xui_mrlb_st xui_mrlb_t;
+typedef struct xui_panel_st xui_panel_t;
+typedef struct xui_mmkedit_s xui_mmkedit_t;
+typedef struct xui_playlist_st xui_playlist_t;
+typedef struct xui_setup_st xui_setup_t;
+typedef struct xui_viewlog_s xui_viewlog_t;
+typedef struct filebrowser_s filebrowser_t;
+typedef struct xui_tvset_s xui_tvset_t;
+typedef struct xui_tvout_s xui_tvout_t;
+typedef struct xui_skdloader_s xui_skdloader_t;
+typedef struct xui_sinfo_s xui_sinfo_t;
+typedef struct xui_lirc_s xui_lirc_t;
+
 #include "config_wrapper.h"
-#include "control.h"
-#include "errors.h"
-#include "event.h"
-#include "event_sender.h"
-#include "help.h"
 #include "i18n.h"
-#include "lang.h"
-#ifdef HAVE_LIRC
-#include "lirc.h"
-#endif
-#include "stdctl.h"
-#include "menus.h"
-#include "mrl_browser.h"
-#include "network.h"
-#include "panel.h"
-#include "playlist.h"
-#include "session.h"
-#include "setup.h"
-#include "skins.h"
-#include "snapshot.h"
-#include "splash.h"
-#include "stream_infos.h"
-#include "tvset.h"
-#include "viewlog.h"
-#include "download.h"
-#include "osd.h"
-#include "file_browser.h"
 #include "post.h"
-#include "tvout.h"
+#include "osd.h"
+#include "kbindings.h"
+#include "mediamark.h"
 
 #include "libcommon.h"
-#include "globals.h"
-#include "dump.h"
 
-#ifdef HAVE_ORBIT 
+#ifdef HAVE_ORBIT
 #include "../corba/xine-server.h"
 #endif
 
-#ifdef HAVE_LIRC
-#include <lirc/lirc_client.h>
-#endif
-
 /*
  * config related constants
  */
@@ -108,12 +92,14 @@ typedef struct gGui_st gGui_t;
 #define SOFTWARE_MIXER          1
 
 /* Playlist loop modes */
-#define PLAYLIST_LOOP_NO_LOOP   0 /* no loop (default) */
-#define PLAYLIST_LOOP_LOOP      1 /* loop the whole playlist */
-#define PLAYLIST_LOOP_REPEAT    2 /* loop the current mrl */
-#define PLAYLIST_LOOP_SHUFFLE   3 /* random selection in playlist */
-#define PLAYLIST_LOOP_SHUF_PLUS 4 /* random selection in playlist, never ending */
-#define PLAYLIST_LOOP_MODES_NUM 5
+typedef enum {
+  PLAYLIST_LOOP_NO_LOOP = 0, /* no loop (default) */
+  PLAYLIST_LOOP_LOOP,        /* loop the whole playlist */
+  PLAYLIST_LOOP_REPEAT,      /* loop the current mrl */
+  PLAYLIST_LOOP_SHUFFLE,     /* random selection in playlist */
+  PLAYLIST_LOOP_SHUF_PLUS,   /* random selection in playlist, never ending */
+  PLAYLIST_LOOP_MODES_NUM
+} playlist_loop_t;
 
 #define PLAYLIST_CONTROL_STOP         0x00000001 /* Don't start next entry in playlist */
 #define PLAYLIST_CONTROL_STOP_PERSIST 0x00000002 /* Don't automatically reset PLAYLIST_CONTROL_STOP */
@@ -132,25 +118,6 @@ typedef struct gGui_st gGui_t;
     }                                                                                         \
   } while(0)
 
-/* Duplicate s to d timeval values */
-#define timercpy(s, d) do {                                                   \
-      (d)->tv_sec = (s)->tv_sec;                                              \
-      (d)->tv_usec = (s)->tv_usec;                                            \
-} while(0)
-
-#ifndef timersub
-#define timersub(a, b, result)                                                \
-  do {                                                                        \
-    (result)->tv_sec = (a)->tv_sec - (b)->tv_sec;                             \
-    (result)->tv_usec = (a)->tv_usec - (b)->tv_usec;                          \
-    if ((result)->tv_usec < 0) {                                              \
-      --(result)->tv_sec;                                                     \
-      (result)->tv_usec += 1000000;                                           \
-    }                                                                         \
-  } while (0)
-#endif
-
-
 /* Our default location for skin downloads */
 #define SKIN_SERVER_URL         "http://xine.sourceforge.net/skins/skins.slx"
 
@@ -167,25 +134,22 @@ typedef struct gGui_st gGui_t;
 #define XUI_W_ON ((xitk_widget_t *)1)
 #define XUI_W_OFF ((xitk_widget_t *)2)
 
+typedef struct skins_locations_s skins_locations_t;
+
 struct gGui_st {
+  struct gGui_st           *nextprev[3];
+
+  char                     *cfg_file;
   xine_t                   *xine;
   xine_video_port_t        *vo_port;
   xine_video_port_t        *vo_none;
   xine_audio_port_t        *ao_none;
 
-  tvout_t                  *tvout;
-
-  post_element_t          **post_video_elements;
-  int                       post_video_elements_num;
+  int                       verbosity;
   int                       post_video_enable;
-  post_element_t          **post_audio_elements;
-  int                       post_audio_elements_num;
   int                       post_audio_enable;
-
-  char                     *deinterlace_plugin;
-  post_element_t          **deinterlace_elements;
-  int                       deinterlace_elements_num;
   int                       deinterlace_enable;
+  int                       lirc_enable;
 
   xine_audio_port_t        *ao_port;
 
@@ -220,15 +184,17 @@ struct gGui_st {
     int                     running;
     int                     current;
     int                     enabled; /* 0, 1:vpost, 2:vanim */
-    
+
     int                     num_mrls;
     char                  **mrls;
-    
+
     int                     post_plugin_num;
     int                     post_changed;
-    post_element_t          post_output_element;    
+    post_element_t          post_output_element;
   } visual_anim;
-  
+
+  post_info_t               post_audio, post_video;
+
   struct {
     int                     enabled;
     int                     use_unscaled;
@@ -255,35 +221,17 @@ struct gGui_st {
   action_id_t               actions_on_start[MAX_ACTIONS_ON_START+1];
   char                     *autoscan_plugin;
 
-  /* basic X11 stuff */
-  void                    (*x_lock_display) (Display *display);
-  void                    (*x_unlock_display) (Display *display);
-  Display                  *display;
-  int                       screen;
-  int		            depth;
-  Visual	           *visual;
-  XColor                    black;
-  Pixmap                    icon;
-  Colormap                  colormap;
-  double                    pixel_aspect;
+  xitk_t                   *xitk;
 
-  VisualID	            prefered_visual_id;
-  int		            prefered_visual_class;
-  int		            install_colormap;
+  /* basic X11 stuff */
+  xitk_image_t             *icon;
 
   xitk_skin_config_t       *skin_config;
   char                     *skin_server_url;
 
-  ImlibData                *imlib_data;
-
-  Display                  *video_display;
-  int                       video_screen;
-  Window                    video_window; 
   int                       cursor_visible;
   int                       cursor_grabbed;
 
-  Window                    panel_window;
-
   uint32_t                  debug_level;
 
   int                       is_display_mrl;
@@ -294,11 +242,11 @@ struct gGui_st {
   mediamark_t               mmk;
   /* Recursive mutex, protecting .mmk and .playlist. */
   pthread_mutex_t           mmk_mutex;
-  
+
   /* playlist */
   struct {
     mediamark_t           **mmk;
-    
+
     int                     num;                   /* number of entries in playlist */
     int                     cur;                   /* current entry in playlist */
     int                     ref_append;            /* append mrl reference entry to this position */
@@ -312,10 +260,6 @@ struct gGui_st {
   int                       ignore_next;
 
   int                       stdctl_enable;
-  
-#ifdef HAVE_XF86VIDMODE
-  int                       XF86VidMode_fullscreen;
-#endif
 
   struct {
     int                     caps; /* MIXER_CAP_x */
@@ -325,14 +269,12 @@ struct gGui_st {
     int                     method;
   } mixer;
 
-  xitk_register_key_t       widget_key;
-
   int                       layer_above;
   int                       always_layer_above;
-  
+
   int                       network;
   int                       network_port;
-  
+
   int                       use_root_window;
 
   int                       ssaver_enabled;
@@ -344,7 +286,7 @@ struct gGui_st {
   int                       auto_panel_visibility;
 
   const char               *snapshot_location;
-  
+
   char                      *keymap_file;
   kbinding_t                *kbindings;
   int                        shortcut_style;
@@ -378,9 +320,8 @@ struct gGui_st {
   FILE                      *report;
 
   int                        no_gui;
-  
+
   int                        no_mouse;
-  int                        wid;
 
   void                     (*nongui_error_msg)(const char *text);
 
@@ -394,96 +335,74 @@ struct gGui_st {
     int                      level;
   } no_messages;
 
+  xitk_window_t             *splash_win;
   xui_panel_t               *panel;
   xui_vwin_t                *vwin;
   xui_setup_t               *setup;
   xui_mrlb_t                *mrlb;
+  xui_actrl_t               *actrl;
   xui_vctrl_t               *vctrl;
+  xui_event_sender_t        *eventer;
+  xui_skdloader_t           *skdloader;
+  xui_help_t                *help;
+  xui_viewlog_t             *viewlog;
+  xui_keyedit_t             *keyedit;
+  xui_playlist_t            *plwin;
+  xui_mmkedit_t             *mmkedit;
+  xui_sinfo_t               *streaminfo;
+  xui_tvset_t               *tvset;
+  xui_tvout_t               *tvout;
+  xui_lirc_t                *lirc;
+  filebrowser_t             *pl_load;
+  filebrowser_t             *pl_save;
 
   /* actions.c */
+  struct {
+    xine_stream_t           *stream;
+    int                      start_pos;
+    int                      start_time_in_secs;
+    int                      update_mmk;
+    int                      running;
+  } play_data;
   filebrowser_t             *load_stream;
   filebrowser_t             *load_sub;
   int                        last_playback_speed;
 
-  /* main.c */
-  char                     **video_driver_ids;
-  char                     **audio_driver_ids;
-  window_attributes_t        window_attribute;
+  struct {
+    int                      (*get_names)(gGui_t *gui, const char **names, int max);
+    xine_sarray_t           *avail;
+    skins_locations_t       *default_skin;
+    skins_locations_t       *current_skin;
+    int                      num;
+    int                      change_config_entry;
+  } skins;
+
+  struct {
+    int                      fd;
+    pthread_t                thread;
+    FILE                    *fbk;
+  } stdctl;
 };
 
 extern gGui_t *gGui;
 
-void set_window_states_start(Window window);
-#define set_window_states_start(window)                                   \
+void set_window_type_start(gGui_t *gui, xitk_window_t *xwin);
+#define set_window_type_start(gui, xwin) \
+  xitk_window_set_wm_window_type (xwin, video_window_is_visible ((gui)->vwin) < 2 ? WINDOW_TYPE_NORMAL : WINDOW_TYPE_NONE)
+
+void set_window_states_start(gGui_t *gui, xitk_window_t *xwin);
+#define set_window_states_start(gui, xwin)                                \
   do {                                                                    \
-    if(!video_window_is_visible(gGui->vwin))                              \
-      xitk_set_wm_window_type((window), WINDOW_TYPE_NORMAL);              \
-    else                                                                  \
-      xitk_unset_wm_window_type((window), WINDOW_TYPE_NORMAL);            \
-    change_class_name((window));                                          \
-    change_icon((window));                                                \
+    set_window_type_start((gui), (xwin));                                 \
+    xitk_window_set_window_class((xwin), NULL, "xine");                   \
+    xitk_window_set_window_icon((xwin), (gui)->icon);                     \
   } while(0)
 
-void reparent_window(Window window);
-#define reparent_window(window)                                                          \
-  do {                                                                                   \
-    if((!(video_window_get_fullscreen_mode(gGui->vwin) & WINDOWED_MODE)) && !wm_not_ewmh_only()) { \
-      XLockDisplay(gGui->display);                                                       \
-      /* Don't unmap this window, because on re-mapping, it will not be visible until    \
-	 its ancestor, the video window, is visible. That's not what's intended.         \
-         XUnmapWindow(gGui->display, (window));                                          \
-      */								                 \
-      if(!video_window_is_visible(gGui->vwin))                                           \
-        xitk_set_wm_window_type((window), WINDOW_TYPE_NORMAL);                           \
-      else                                                                               \
-        xitk_unset_wm_window_type((window), WINDOW_TYPE_NORMAL);                         \
-      XRaiseWindow(gGui->display, (window));                                             \
-      XMapWindow(gGui->display, (window));                                               \
-      try_to_set_input_focus((window));                                                  \
-      if(!gGui->use_root_window && gGui->video_display == gGui->display)                 \
-        XSetTransientForHint (gGui->display, (window), gGui->video_window);              \
-      XUnlockDisplay(gGui->display);                                                     \
-    }                                                                                    \
-    else {                                                                               \
-      XLockDisplay(gGui->display);                                                       \
-      XRaiseWindow(gGui->display, window);                                               \
-      XMapWindow(gGui->display, window);                                                 \
-      if(!gGui->use_root_window && gGui->video_display == gGui->display)                 \
-        XSetTransientForHint (gGui->display, window, gGui->video_window);                \
-      XUnlockDisplay(gGui->display);                                                     \
-      layer_above_video(window);                                                         \
-    }                                                                                    \
-  } while(0)
+void reparent_window(gGui_t *gui, xitk_window_t *xwin);
 
-void change_class_name(Window window);
-#define change_class_name(window)                                         \
-  do {                                                                    \
-    XClassHint  xclasshint;                                               \
-    XLockDisplay (gGui->display);                                         \
-    if((XGetClassHint(gGui->display, (window), &xclasshint)) != 0) {      \
-      XClassHint   nxclasshint;                                           \
-      nxclasshint.res_name = xclasshint.res_name;                         \
-      nxclasshint.res_class = "xine";                                     \
-      XSetClassHint(gGui->display, window, &nxclasshint);                 \
-      XFree(xclasshint.res_name);                                         \
-      XFree(xclasshint.res_class);                                        \
-    }                                                                     \
-    XUnlockDisplay (gGui->display);                                       \
-  } while(0)
 
-void change_icon(Window window);
-#define change_icon(window)                                               \
-  do {                                                                    \
-    XWMHints *wmhints;                                                    \
-    XLockDisplay(gGui->display);                                          \
-    if((wmhints = XAllocWMHints())) {                                     \
-      wmhints->icon_pixmap   = gGui->icon;                                \
-      wmhints->flags         = IconPixmapHint;                            \
-      XSetWMHints(gGui->display, (window), wmhints);                      \
-      XFree(wmhints);                                                     \
-    }                                                                     \
-    XUnlockDisplay(gGui->display);                                        \
-  } while(0)
+void gui_load_window_pos (gGui_t *gui, const char *name, int *x, int *y);
+void gui_save_window_pos (gGui_t *gui, const char *name, xitk_register_key_t key);
 
 #ifdef HAVE_XML_PARSER_REENTRANT
 # define xml_parser_init_R(X,D,L,M) X = xml_parser_init_r ((D), (L), (M))
