@@ -1,18 +1,18 @@
-/* 
- * Copyright (C) 2000-2019 the xine project
- * 
+/*
+ * Copyright (C) 2000-2021 the xine project
+ *
  * This file is part of xine, a unix video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
@@ -25,13 +25,25 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/extensions/shape.h>
-#include <X11/keysym.h>
 #include <pthread.h>
 
 #include "common.h"
+#include "actions.h"
+#include "event.h"
+#include "kbindings.h"
+#include "control.h"
+#include "skins.h"
+#include "menus.h"
+#include "videowin.h"
+#include "panel.h"
+#include "errors.h"
+#include "xine-toolkit/backend.h"
+#include "xine-toolkit/slider.h"
+#include "xine-toolkit/label.h"
+#include "xine-toolkit/labelbutton.h"
+#include "xine-toolkit/combo.h"
+#include "xine-toolkit/browser.h"
+#include "xine-toolkit/skin.h"
 #include <xine/video_out.h>
 
 #define CONTROL_MIN     0
@@ -41,6 +53,7 @@
 
 #define TEST_VO_VALUE(val)  (val < CONTROL_MAX/3 || val > CONTROL_MAX*2/3) ? (CONTROL_MAX - val) : 0
 
+
 typedef struct {
   xui_vctrl_t   *vctrl;
   char          *name;
@@ -62,9 +75,8 @@ struct xui_vctrl_st {
 #define NUM_SLIDERS 7
   vctrl_item_t          items[NUM_SLIDERS];
 
-  Window                window;
+  xitk_window_t        *xwin;
 
-  ImlibImage           *bg_image;
   xitk_widget_list_t   *widget_list;
 
   xitk_widget_t        *skinlist;
@@ -77,27 +89,54 @@ struct xui_vctrl_st {
   xitk_widget_t         *combo;
 };
 
-static void control_select_new_skin (xitk_widget_t *w, void *data, int selected) {
+static void _control_set (vctrl_item_t *item, int value) {
+  int real_value;
+
+  if (!item->enable)
+    return;
+
+  if (value < CONTROL_MIN)
+    value = CONTROL_MIN;
+  if (value > CONTROL_MAX)
+    value = CONTROL_MAX;
+  if (value == item->value)
+    return;
+
+  xine_set_param (item->vctrl->gui->stream, item->prop, value);
+  real_value = xine_get_param (item->vctrl->gui->stream, item->prop);
+  /* xine video out may support just a few coarse steps, and snap us back.
+   * escape this black hole while we still can. */
+  if (value > item->value) {
+    if (real_value > item->value)
+      value = real_value;
+  } else {
+    if (real_value < item->value)
+      value = real_value;
+  }
+  item->value = value;
+  osd_draw_bar (item->vctrl->gui, item->name, 0, 65535, value, OSD_BAR_STEPPER);
+  if (item->w && xitk_is_widget_enabled (item->w))
+    xitk_slider_set_pos (item->w, value);
+}
+
+static void control_select_new_skin (xitk_widget_t *w, void *data, int selected, int modifier) {
   xui_vctrl_t *vctrl = data;
 
   (void)w;
-  if (vctrl) {
+  (void)modifier;
+  if (vctrl && (selected >= 0)) {
     xitk_browser_release_all_buttons (vctrl->skinlist);
-    select_new_skin (selected);
+    skin_select (vctrl->gui, selected);
   }
 }
 
 static void control_set_value (xitk_widget_t *w, void *data, int value) {
   vctrl_item_t *item = data;
-  int new_value;
 
   (void)w;
-  xine_set_param (item->vctrl->gui->stream, item->prop, value);
-  new_value = xine_get_param (item->vctrl->gui->stream, item->prop);
-  if ((new_value != value) && item->w && xitk_is_widget_enabled (item->w))
-    xitk_slider_set_pos (item->w, new_value);
+  _control_set (item, value);
   if (item->enable)
-    config_update_num (item->cfg, new_value);
+    config_update_num (item->vctrl->gui->xine, item->cfg, value);
 }
 
 static void control_changes_cb (void *data, xine_cfg_entry_t *cfg) {
@@ -252,7 +291,6 @@ xui_vctrl_t *control_init (gGui_t *gui) {
   }
 
   /* defer all window stuff to first use. */
-  vctrl->window = None;
   vctrl->status = 1;
 
   vctrl->gui->vctrl = vctrl;
@@ -262,150 +300,81 @@ xui_vctrl_t *control_init (gGui_t *gui) {
 /*
  * Handle X events here.
  */
-static void control_handle_event(XEvent *event, void *data) {
-  xui_vctrl_t *vctrl = data;
-  
-  switch(event->type) {
-  case ButtonPress: {
-    XButtonEvent *bevent = (XButtonEvent *) event;
-    
-    if(bevent->button == Button3) {
-      int wx, wy;
-      
-      xitk_get_window_position (vctrl->gui->display, vctrl->window, &wx, &wy, NULL, NULL);
-      control_menu (vctrl->gui, vctrl->widget_list, bevent->x + wx, bevent->y + wy);
-    }
-  }
 
-  case KeyPress:
-    if(xitk_get_key_pressed(event) == XK_Escape)
+static int control_event (void *data, const xitk_be_event_t *e) {
+  xui_vctrl_t *vctrl = data;
+
+  switch (e->type) {
+    case XITK_EV_DEL_WIN:
       control_toggle_window (NULL, vctrl);
-    else
-      gui_handle_event (event, vctrl->gui);
-    break;
-    
+      return 1;
+    case XITK_EV_BUTTON_DOWN:
+      if (e->code == 3) {
+        control_menu (vctrl->gui, vctrl->widget_list, e->w, e->h);
+        return 1;
+      }
+      break;
+    case XITK_EV_KEY_DOWN:
+      if (e->utf8[0] == XITK_CTRL_KEY_PREFIX) {
+        if (e->utf8[1] == XITK_KEY_ESCAPE) {
+          control_toggle_window (NULL, vctrl);
+          return 1;
+        }
+        if (e->utf8[1] == XITK_KEY_MENU) {
+          control_menu (vctrl->gui, vctrl->widget_list, e->w, e->h);
+          return 1;
+        }
+      }
+      break;
+    default: ;
   }
-  
+  return gui_handle_be_event (vctrl->gui, e);
+}
+
+static void _control_toggle_window (xitk_widget_t *w, void *data, int state) {
+  (void)state;
+  control_toggle_window (w, data);
 }
 
 /*
  * Create control panel window
  */
 static int vctrl_open_window (xui_vctrl_t *vctrl) {
-  GC                         gc;
-  XSizeHints                 hint;
-  XSetWindowAttributes       attr;
-  char                      *title = _("xine Control Window");
-  Atom                       prop;
   xitk_browser_widget_t      br;
   xitk_labelbutton_widget_t  lb;
   xitk_label_widget_t        lbl;
-  xitk_combo_widget_t        cmb;
   xitk_widget_t             *w;
+  xitk_image_t              *bg_image;
+  int x, y, width, height;
 
-  XITK_WIDGET_INIT (&br, vctrl->gui->imlib_data);
-  XITK_WIDGET_INIT (&lb, vctrl->gui->imlib_data);
-  XITK_WIDGET_INIT (&cmb, vctrl->gui->imlib_data);
+  XITK_WIDGET_INIT (&br);
+  XITK_WIDGET_INIT (&lb);
 
-  vctrl->gui->x_lock_display (vctrl->gui->display);
-  vctrl->bg_image = Imlib_load_image (vctrl->gui->imlib_data,
-    xitk_skin_get_skin_filename (vctrl->gui->skin_config, "CtlBG"));
-  if (!vctrl->bg_image) {
-    xine_error(_("control: couldn't find image for background\n"));
+  {
+    const xitk_skin_element_info_t *info = xitk_skin_get_info (vctrl->gui->skin_config, "CtlBG");
+    bg_image = info ? info->pixmap_img.image : NULL;
+  }
+  if (!bg_image) {
+    gui_msg (vctrl->gui, XUI_MSG_ERROR, _("control: couldn't find image for background\n"));
     exit(-1);
   }
-  vctrl->gui->x_unlock_display (vctrl->gui->display);
 
-  hint.x = xine_config_register_num (vctrl->gui->xine, "gui.control_x",
-    200, CONFIG_NO_DESC, CONFIG_NO_HELP, CONFIG_LEVEL_DEB, CONFIG_NO_CB, CONFIG_NO_DATA);
-  hint.y = xine_config_register_num (vctrl->gui->xine, "gui.control_y",
-    100, CONFIG_NO_DESC, CONFIG_NO_HELP, CONFIG_LEVEL_DEB, CONFIG_NO_CB, CONFIG_NO_DATA);
-  hint.width = vctrl->bg_image->rgb_width;
-  hint.height = vctrl->bg_image->rgb_height;
-  hint.flags = PPosition | PSize;
-  
-  attr.override_redirect = False;
-  attr.background_pixel  = vctrl->gui->black.pixel;
-  /*
-   * XXX:multivis
-   * To avoid BadMatch errors on XCreateWindow:
-   * If the parent and the new window have different depths, we must supply either
-   * a BorderPixmap or a BorderPixel.
-   * If the parent and the new window use different visuals, we must supply a
-   * Colormap
-   */
-  attr.border_pixel      = 1;
+  x = 200;
+  y = 100;
+  gui_load_window_pos (vctrl->gui, "control", &x, &y);
+  width = xitk_image_width(bg_image);
+  height = xitk_image_height(bg_image);
 
-  vctrl->gui->x_lock_display (vctrl->gui->display);
-  attr.colormap = Imlib_get_colormap (vctrl->gui->imlib_data);
-  vctrl->window = XCreateWindow (vctrl->gui->display, vctrl->gui->imlib_data->x.root,
-    hint.x, hint.y, hint.width, hint.height, 0,
-    vctrl->gui->imlib_data->x.depth, InputOutput, vctrl->gui->imlib_data->x.visual,
-    CWBackPixel | CWBorderPixel | CWColormap | CWOverrideRedirect, &attr);
-  XmbSetWMProperties (vctrl->gui->display, vctrl->window, _(title), _(title), NULL, 0, &hint, NULL, NULL);
-  XSelectInput (vctrl->gui->display, vctrl->window, INPUT_MOTION | KeymapStateMask);
-  vctrl->gui->x_unlock_display (vctrl->gui->display);
-
-  if (!video_window_is_visible (vctrl->gui->vwin))
-    xitk_set_wm_window_type (vctrl->window, WINDOW_TYPE_NORMAL);
-  else
-    xitk_unset_wm_window_type (vctrl->window, WINDOW_TYPE_NORMAL);
-  
-  if (is_layer_above ())
-    xitk_set_layer_above (vctrl->window);
-
-  /* wm, no border please */
-  {
-    MWMHints mwmhints;
-
-    memset (&mwmhints, 0, sizeof (mwmhints));
-    vctrl->gui->x_lock_display (vctrl->gui->display);
-    prop = XInternAtom (vctrl->gui->display, "_MOTIF_WM_HINTS", True);
-    mwmhints.flags = MWM_HINTS_DECORATIONS;
-    mwmhints.decorations = 0;
-    XChangeProperty (vctrl->gui->display, vctrl->window, prop, prop, 32,
-      PropModeReplace, (unsigned char *)&mwmhints, PROP_MWM_HINTS_ELEMENTS);
-  }
-
-  /* set xclass */
-  {
-    XClassHint *xclasshint = XAllocClassHint ();
-
-    if (xclasshint) {
-      xclasshint->res_name = title;
-      xclasshint->res_class = "xine";
-      XSetClassHint (vctrl->gui->display, vctrl->window, xclasshint);
-      XFree (xclasshint);
-    }
-  }
-
-  {
-    XWMHints *wm_hint = XAllocWMHints ();
-
-    if (wm_hint) {
-      wm_hint->input         = True;
-      wm_hint->initial_state = NormalState;
-      wm_hint->icon_pixmap   = vctrl->gui->icon;
-      wm_hint->flags         = InputHint | StateHint | IconPixmapHint;
-      XSetWMHints (vctrl->gui->display, vctrl->window, wm_hint);
-      XFree (wm_hint);
-    }
-  }
-  
-  gc = XCreateGC (vctrl->gui->display, vctrl->window, 0, 0);
-  Imlib_apply_image (vctrl->gui->imlib_data, vctrl->bg_image, vctrl->window);
-  vctrl->gui->x_unlock_display (vctrl->gui->display);
+  vctrl->xwin = xitk_window_create_window_ext (vctrl->gui->xitk, x + 100, y + 100, width, height,
+    _("xine Control Window"), NULL, "xine", 0, is_layer_above (vctrl->gui), vctrl->gui->icon, bg_image);
+  set_window_type_start(vctrl->gui, vctrl->xwin);
 
   /*
    * Widget-list
    */
-  vctrl->widget_list = xitk_widget_list_new ();
-  xitk_widget_list_set (vctrl->widget_list, WIDGET_LIST_WINDOW, (void *)vctrl->window);
-  xitk_widget_list_set (vctrl->widget_list, WIDGET_LIST_GC, gc);
-  
-  XITK_WIDGET_INIT (&lbl, vctrl->gui->imlib_data);
-  lbl.window = XITK_WIDGET_LIST_WINDOW (vctrl->widget_list);
-  lbl.gc     = XITK_WIDGET_LIST_GC (vctrl->widget_list);
+  vctrl->widget_list = xitk_window_widget_list(vctrl->xwin);
+
+  XITK_WIDGET_INIT (&lbl);
   lbl.callback = NULL;
 
   {
@@ -420,7 +389,7 @@ static int vctrl_open_window (xui_vctrl_t *vctrl) {
     xitk_slider_widget_t sl;
     unsigned int u;
 
-    XITK_WIDGET_INIT (&sl, vctrl->gui->imlib_data);
+    XITK_WIDGET_INIT (&sl);
     sl.min    = CONTROL_MIN;
     sl.max    = CONTROL_MAX;
     sl.step   = CONTROL_STEP;
@@ -429,44 +398,37 @@ static int vctrl_open_window (xui_vctrl_t *vctrl) {
 
     for (u = 0; u < NUM_SLIDERS; u++) {
       vctrl_item_t *item = &vctrl->items[u];
+      /*
       int v;
 
       if (item->enable)
         v = xine_get_param (vctrl->gui->stream, item->prop);
       else
         v = CONTROL_MIN;
-      sl.skin_element_name = (char *)sl_skins[u];
+      */
+      sl.skin_element_name = sl_skins[u];
       sl.userdata        =
       sl.motion_userdata = item;
       item->w = xitk_slider_create (vctrl->widget_list, vctrl->gui->skin_config, &sl);
       if (item->w) {
-        xitk_add_widget (vctrl->widget_list, item->w);
+        xitk_add_widget (vctrl->widget_list, item->w, (item->enable ? XITK_WIDGET_STATE_ENABLE : 0) | XITK_WIDGET_STATE_VISIBLE);
         xitk_slider_set_pos (item->w, item->value);
         xitk_set_widget_tips (item->w, item->hint);
-        if (item->enable)
-          xitk_enable_widget (item->w);
-        else
-          xitk_disable_widget (item->w);
       }
-      lbl.skin_element_name = (char *)lbl_skins[u];
+      lbl.skin_element_name = lbl_skins[u];
       lbl.label             = item->label;
-      xitk_add_widget (vctrl->widget_list, xitk_label_create (vctrl->widget_list, vctrl->gui->skin_config, &lbl));
+      xitk_add_widget (vctrl->widget_list, xitk_label_create (vctrl->widget_list, vctrl->gui->skin_config, &lbl),
+        XITK_WIDGET_STATE_ENABLE | XITK_WIDGET_STATE_VISIBLE);
     }
   }
 
-  {
-    skins_locations_t **sks = get_available_skins ();
-    int i;
+  vctrl->skins_num = skin_get_names (vctrl->gui, vctrl->skins, sizeof (vctrl->skins) / sizeof (vctrl->skins[0]));
 
-    vctrl->skins_num = get_available_skins_num ();
-    for (i = 0; i < vctrl->skins_num; i++)
-      vctrl->skins[i] = strdup (sks[i]->skin);
-  }
-  
   lbl.skin_element_name = "CtlSkLbl";
   /* TRANSLATORS: only ASCII characters (skin) */
   lbl.label             = pgettext("skin", "Choose a Skin");
-  xitk_add_widget (vctrl->widget_list, xitk_label_create (vctrl->widget_list, vctrl->gui->skin_config, &lbl));
+  xitk_add_widget (vctrl->widget_list, xitk_label_create (vctrl->widget_list, vctrl->gui->skin_config, &lbl),
+    XITK_WIDGET_STATE_ENABLE | XITK_WIDGET_STATE_VISIBLE);
 
   br.arrow_up.skin_element_name    = "CtlSkUp";
   br.slider.skin_element_name      = "SliderCtlSk";
@@ -480,9 +442,8 @@ static int vctrl_open_window (xui_vctrl_t *vctrl) {
   br.callback                      =
   br.dbl_click_callback            = control_select_new_skin;
   br.userdata                      = vctrl;
-  br.parent_wlist                  = vctrl->widget_list;
   vctrl->skinlist = xitk_browser_create (vctrl->widget_list, vctrl->gui->skin_config, &br);
-  xitk_add_widget (vctrl->widget_list, vctrl->skinlist);
+  xitk_add_widget (vctrl->widget_list, vctrl->skinlist, XITK_WIDGET_STATE_ENABLE | XITK_WIDGET_STATE_VISIBLE);
 
   xitk_browser_update_list (vctrl->skinlist, vctrl->skins, NULL, vctrl->skins_num, 0);
 
@@ -490,121 +451,52 @@ static int vctrl_open_window (xui_vctrl_t *vctrl) {
   lb.button_type       = CLICK_BUTTON;
   lb.align             = ALIGN_DEFAULT;
   lb.label             = _("Dismiss");
-  lb.callback          = control_toggle_window;
+  lb.callback          = _control_toggle_window;
   lb.state_callback    = NULL;
   lb.userdata          = vctrl;
   w = xitk_labelbutton_create (vctrl->widget_list, vctrl->gui->skin_config, &lb);
-  xitk_add_widget (vctrl->widget_list, w);
+  xitk_add_widget (vctrl->widget_list, w, XITK_WIDGET_STATE_ENABLE | XITK_WIDGET_STATE_VISIBLE);
   xitk_set_widget_tips(w, _("Close control window"));
 
-  control_show_tips (vctrl, panel_get_tips_enable (vctrl->gui->panel), panel_get_tips_timeout (vctrl->gui->panel));
+  vctrl->widget_key = xitk_be_register_event_handler ("control", vctrl->xwin, control_event, vctrl, NULL, NULL);
 
-  vctrl->widget_key = xitk_register_event_handler ("control",
-    vctrl->window, control_handle_event, NULL,
-    gui_dndcallback, vctrl->widget_list, vctrl);
-  
   vctrl->status = 3;
   control_raise_window (vctrl);
-  
-  try_to_set_input_focus (vctrl->window);
+
+  xitk_window_set_input_focus (vctrl->xwin);
   return 1;
 }
 
 static void vctrl_close_window (xui_vctrl_t *vctrl) {
   vctrl->status = 1;
 
-  if (vctrl->window != None) {
-    window_info_t wi;
+  if (vctrl->xwin) {
     int           i;
-    
-    if ((xitk_get_window_info (vctrl->widget_key, &wi))) {
-      config_update_num ("gui.control_x", wi.x);
-      config_update_num ("gui.control_y", wi.y);
-    }
 
-    xitk_unregister_event_handler (&vctrl->widget_key);
+    gui_save_window_pos (vctrl->gui, "control", vctrl->widget_key);
 
-    vctrl->gui->x_lock_display (vctrl->gui->display);
-    XUnmapWindow (vctrl->gui->display, vctrl->window);
-    vctrl->gui->x_unlock_display (vctrl->gui->display);
+    xitk_unregister_event_handler (vctrl->gui->xitk, &vctrl->widget_key);
 
-    xitk_destroy_widgets (vctrl->widget_list);
+    xitk_window_destroy_window(vctrl->xwin);
+    vctrl->xwin = NULL;
 
-    vctrl->gui->x_lock_display (vctrl->gui->display);
-    XDestroyWindow (vctrl->gui->display, vctrl->window);
-    Imlib_destroy_image (vctrl->gui->imlib_data, vctrl->bg_image);
-    vctrl->gui->x_unlock_display (vctrl->gui->display);
-
-    vctrl->window = None;
     /* xitk_dlist_init (&control->widget_list->list); */
 
-    vctrl->gui->x_lock_display (vctrl->gui->display);
-    XFreeGC (vctrl->gui->display, (XITK_WIDGET_LIST_GC (vctrl->widget_list)));
-    vctrl->gui->x_unlock_display (vctrl->gui->display);
-
-    XITK_WIDGET_LIST_FREE (vctrl->widget_list);
-
-    for (i = 0; i < vctrl->skins_num; i++)
-      free ((char *)vctrl->skins[i]);
-
     for (i = 0; i < NUM_SLIDERS; i++)
       vctrl->items[0].w = NULL;
   }
 
-  try_to_set_input_focus (vctrl->gui->video_window);
+  video_window_set_input_focus (vctrl->gui->vwin);
 }
 
-void control_dec_image_prop (xui_vctrl_t *vctrl, int prop) {
-  if (vctrl) {
-    vctrl_item_t *item;
-    unsigned int u;
+void control_action (xui_vctrl_t *vctrl, action_id_t action) {
+  if (vctrl && (action >= ACTID_HUECONTROLp)) {
+    unsigned int u = action - ACTID_HUECONTROLp;
 
-    for (u = 0; u < NUM_SLIDERS; u++) {
-      item = &vctrl->items[u];
-      if (item->prop == prop)
-        break;
-    }
-    if (u < NUM_SLIDERS) {
-      int v = item->value - STEP_SIZE;
-      if (v < 0)
-        v = 0;
-      if (item->enable) {
-        xine_set_param (item->vctrl->gui->stream, item->prop, v);
-        /* not doing this here because xine video out may support
-         * just a few coarse steps, and snap us back. in other words:
-         * we are stuck inside a black hole.
-        v = xine_get_param (item->vctrl->gui->stream, item->prop);
-        */
-        item->value = v;
-        osd_draw_bar (item->name, 0, 65535, v, OSD_BAR_STEPPER);
-        if (item->w && xitk_is_widget_enabled (item->w))
-          xitk_slider_set_pos (item->w, v);
-      }
-    }
-  }
-}
+    if (u < 2 * NUM_SLIDERS) {
+      vctrl_item_t *item = vctrl->items + (u >> 1);
 
-void control_inc_image_prop (xui_vctrl_t *vctrl, int prop) {
-  if (vctrl) {
-    vctrl_item_t *item;
-    unsigned int u;
-
-    for (u = 0; u < NUM_SLIDERS; u++) {
-      item = &vctrl->items[u];
-      if (item->prop == prop)
-        break;
-    }
-    if (u < NUM_SLIDERS) {
-      int v = item->value + STEP_SIZE;
-      if (v > 65535)
-        v = 65535;
-      if (item->enable) {
-        xine_set_param (item->vctrl->gui->stream, item->prop, v);
-        item->value = v;
-        osd_draw_bar (item->name, 0, 65535, v, OSD_BAR_STEPPER);
-        if (item->w && xitk_is_widget_enabled (item->w))
-          xitk_slider_set_pos (item->w, v);
-      }
+      _control_set (item, item->value + ((u & 1) ? -STEP_SIZE : STEP_SIZE));
     }
   }
 }
@@ -618,7 +510,7 @@ void control_reset (xui_vctrl_t *vctrl) {
 
       if (item->enable) {
         xine_set_param (vctrl->gui->stream, item->prop, item->default_value);
-        config_update_num (item->cfg, -1);
+        config_update_num (vctrl->gui->xine, item->cfg, -1);
         if (item->w && xitk_is_widget_enabled (item->w))
           xitk_slider_set_pos (item->w, item->default_value);
       }
@@ -627,22 +519,6 @@ void control_reset (xui_vctrl_t *vctrl) {
 }
 
 /*
- *
- */
-void control_show_tips (xui_vctrl_t *vctrl, int enabled, unsigned long timeout) {
-  if (vctrl) {
-    if (enabled)
-      xitk_set_widgets_tips_timeout (vctrl->widget_list, timeout);
-    else
-      xitk_disable_widgets_tips (vctrl->widget_list);
-  }
-}
-
-void control_update_tips_timeout (xui_vctrl_t *vctrl, unsigned long timeout) {
-  if (vctrl)
-    xitk_set_widgets_tips_timeout (vctrl->widget_list, timeout);
-}
-
 int control_status (xui_vctrl_t *vctrl) {
   if (!vctrl)
     return 0;
@@ -650,8 +526,9 @@ int control_status (xui_vctrl_t *vctrl) {
     return 1;
   if (!vctrl->gui->use_root_window && (vctrl->status == 2))
     return 2;
-  return (!!xitk_is_window_visible (vctrl->gui->display, vctrl->window)) + 2;
+  return (!!(xitk_window_flags (vctrl->xwin, 0, 0) & XITK_WINF_VISIBLE)) + 2;
 }
+*/
 
 /*
  * Raise control->window
@@ -660,28 +537,19 @@ void control_raise_window (xui_vctrl_t *vctrl) {
   if (vctrl && (vctrl->status >= 2)) {
     int visible = vctrl->status - 2;
 
-    raise_window (vctrl->window, visible, 1);
+    raise_window (vctrl->gui, vctrl->xwin, visible, 1);
   }
 }
 
 /*
  * Hide/show the control panel
  */
-void control_toggle_visibility (xitk_widget_t *w, void *data) {
-  xui_vctrl_t *vctrl = data;
-
+void control_toggle_visibility (xui_vctrl_t *vctrl) {
   if (vctrl && (vctrl->status >= 2)) {
     int visible;
 
-    if (w == XUI_W_ON) {
-      if (vctrl->status == 3)
-        return;
-    } else if (w == XUI_W_OFF) {
-      if (vctrl->status == 2)
-        return;
-    }
     visible = vctrl->status - 2;
-    toggle_window (vctrl->window, vctrl->widget_list, &visible, 1);
+    toggle_window (vctrl->gui, vctrl->xwin, vctrl->widget_list, &visible, 1);
     vctrl->status = visible + 2;
   }
 }
@@ -706,7 +574,7 @@ void control_toggle_window (xitk_widget_t *w, void *data) {
         vctrl_open_window (vctrl);
       } else {
         int visible = 0;
-        toggle_window (vctrl->window, vctrl->widget_list, &visible, 1);
+        toggle_window (vctrl->gui, vctrl->xwin, vctrl->widget_list, &visible, 1);
         vctrl->status = visible + 2;
       }
     } else {
@@ -719,52 +587,30 @@ void control_toggle_window (xitk_widget_t *w, void *data) {
  * Change the current skin.
  */
 void control_change_skins (xui_vctrl_t *vctrl, int synthetic) {
-  ImlibImage   *new_img, *old_img;
-  XSizeHints    hint;
 
   if (vctrl->status >= 2) {
-    
+    xitk_image_t *bg_image;
+
     xitk_skin_lock (vctrl->gui->skin_config);
     xitk_hide_widgets (vctrl->widget_list);
 
-    vctrl->gui->x_lock_display (vctrl->gui->display);
-    
-    if (!(new_img = Imlib_load_image (vctrl->gui->imlib_data,
-      xitk_skin_get_skin_filename (vctrl->gui->skin_config, "CtlBG")))) {
-      xine_error(_("%s(): couldn't find image for background\n"), __XINE_FUNCTION__);
+    {
+      const xitk_skin_element_info_t *info = xitk_skin_get_info (vctrl->gui->skin_config, "CtlBG");
+      bg_image = info ? info->pixmap_img.image : NULL;
+    }
+    if (!bg_image) {
+      gui_msg (vctrl->gui, XUI_MSG_ERROR, _("%s(): couldn't find image for background\n"), __XINE_FUNCTION__);
       exit(-1);
     }
-    vctrl->gui->x_unlock_display (vctrl->gui->display);
 
-    hint.width  = new_img->rgb_width;
-    hint.height = new_img->rgb_height;
-    hint.flags  = PPosition | PSize;
+    xitk_window_set_background_image (vctrl->xwin, bg_image);
 
-    vctrl->gui->x_lock_display (vctrl->gui->display);
-    XSetWMNormalHints (vctrl->gui->display, vctrl->window, &hint);
-    XResizeWindow (vctrl->gui->display, vctrl->window,
-      (unsigned int)new_img->rgb_width, (unsigned int)new_img->rgb_height);
-    vctrl->gui->x_unlock_display (vctrl->gui->display);
-    
-    while (!xitk_is_window_size (vctrl->gui->display, vctrl->window,
-      new_img->rgb_width, new_img->rgb_height)) {
-      xine_usec_sleep(10000);
-    }
-    
-    old_img = vctrl->bg_image;
-    vctrl->bg_image = new_img;
-    
-    vctrl->gui->x_lock_display (vctrl->gui->display);
-    if (!vctrl->gui->use_root_window && vctrl->gui->video_display == vctrl->gui->display)
-      XSetTransientForHint (vctrl->gui->display, vctrl->window, vctrl->gui->video_window);
-    Imlib_destroy_image (vctrl->gui->imlib_data, old_img);
-    Imlib_apply_image (vctrl->gui->imlib_data, new_img, vctrl->window);
-    vctrl->gui->x_unlock_display (vctrl->gui->display);
+    video_window_set_transient_for (vctrl->gui->vwin, vctrl->xwin);
 
     control_raise_window (vctrl);
 
     xitk_skin_unlock (vctrl->gui->skin_config);
-    
+
     xitk_change_skins_widget_list (vctrl->widget_list, vctrl->gui->skin_config);
     xitk_paint_widget_list (vctrl->widget_list);
 
@@ -774,10 +620,7 @@ void control_change_skins (xui_vctrl_t *vctrl, int synthetic) {
       for (u = 0; u < NUM_SLIDERS; u++) {
         vctrl_item_t *item = &vctrl->items[u];
 
-        if (item->enable)
-          xitk_enable_widget (item->w);
-        else
-          xitk_disable_widget (item->w);
+        xitk_widgets_state (&item->w, 1, XITK_WIDGET_STATE_ENABLE, item->enable ? ~0u : 0);
       }
     }
   }
@@ -796,9 +639,3 @@ void control_deinit (xui_vctrl_t *vctrl) {
     free (vctrl);
   }
 }
-
-void control_reparent (xui_vctrl_t *vctrl) {
-  if (vctrl && (vctrl->window != None))
-    reparent_window (vctrl->window);
-}
-
