@@ -1,18 +1,18 @@
-/* 
- * Copyright (C) 2000-2014 the xine project
- * 
+/*
+ * Copyright (C) 2000-2021 the xine project
+ *
  * This file is part of xine, a unix video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
@@ -22,14 +22,15 @@
 #define KBINDINGS_H
 
 #include "xitk.h"
+#include "backend.h"
 
 /* Opaque structure */
 typedef struct kbinding_s kbinding_t;
 typedef struct kbinding_entry_s kbinding_entry_t;
 
-/* 
- * This bit is turned on in the enum below to indicate there is 
- * a corresponding definition xine-lib's events.h 
+/*
+ * This bit is turned on in the enum below to indicate there is
+ * a corresponding definition xine-lib's events.h
  */
 #define ACTID_IS_INPUT_EVENT 0x400
 
@@ -43,6 +44,7 @@ typedef enum {
   ACTID_SPU_NEXT,
   ACTID_SPU_PRIOR,
   ACTID_CONTROLSHOW,
+  ACTID_ACONTROLSHOW,
   ACTID_TOGGLE_WINOUT_VISIBLITY,
   ACTID_TOGGLE_WINOUT_BORDER,
   ACTID_AUDIOCHAN_NEXT,
@@ -66,6 +68,7 @@ typedef enum {
   ACTID_MRL_SELECT,
   ACTID_EVENT_SENDER,
   ACTID_EJECT,
+  /* keep order, see event.c */
   ACTID_SET_CURPOS,
   ACTID_SET_CURPOS_0,
   ACTID_SET_CURPOS_10,
@@ -78,8 +81,10 @@ typedef enum {
   ACTID_SET_CURPOS_80,
   ACTID_SET_CURPOS_90,
   ACTID_SET_CURPOS_100,
+  /* /keep order */
   ACTID_SEEK_REL_m,
   ACTID_SEEK_REL_p,
+  /* keep order, see event.c */
   ACTID_SEEK_REL_m60,
   ACTID_SEEK_REL_p60,
   ACTID_SEEK_REL_m15,
@@ -88,11 +93,14 @@ typedef enum {
   ACTID_SEEK_REL_p30,
   ACTID_SEEK_REL_m7,
   ACTID_SEEK_REL_p7,
+  /* /keep order */
   ACTID_MRLBROWSER,
   ACTID_MUTE,
-  ACTID_AV_SYNC_p3600,
+  /* keep order */
   ACTID_AV_SYNC_m3600,
   ACTID_AV_SYNC_RESET,
+  ACTID_AV_SYNC_p3600,
+  /* /keep order */
   ACTID_SPEED_FAST,
   ACTID_SPEED_SLOW,
   ACTID_SPEED_RESET,
@@ -104,6 +112,7 @@ typedef enum {
   ACTID_SNAPSHOT,
   ACTID_ZOOM_1_1,
   ACTID_GRAB_POINTER,
+  /* keep order */
   ACTID_ZOOM_IN,
   ACTID_ZOOM_OUT,
   ACTID_ZOOM_X_IN,
@@ -111,6 +120,7 @@ typedef enum {
   ACTID_ZOOM_Y_IN,
   ACTID_ZOOM_Y_OUT,
   ACTID_ZOOM_RESET,
+  /* /keep order */
   ACTID_TOGGLE_TVMODE,
   ACTID_TVANALOG,
   ACTID_SETUP,
@@ -128,9 +138,12 @@ typedef enum {
   ACTID_OSD_WTEXT,
   ACTID_FILESELECTOR,
   ACTID_SUBSELECT,
-  ACTID_SV_SYNC_p,
+  /* keep order */
   ACTID_SV_SYNC_m,
   ACTID_SV_SYNC_RESET,
+  ACTID_SV_SYNC_p,
+  /* /keep order */
+  /* keep order */
   ACTID_HUECONTROLp,
   ACTID_HUECONTROLm,
   ACTID_SATURATIONCONTROLp,
@@ -145,6 +158,7 @@ typedef enum {
   ACTID_SHARPNESSCONTROLm,
   ACTID_NOISEREDUCTIONCONTROLp,
   ACTID_NOISEREDUCTIONCONTROLm,
+  /* /keep order */
   ACTID_VPP,
   ACTID_VPP_ENABLE,
   ACTID_HELP_SHOW,
@@ -160,7 +174,7 @@ typedef enum {
   ACTID_PLAYLIST_OPEN,
 
   /*
-   * The below events map one-to-one with definitions in xine-lib's events.h 
+   * The below events map one-to-one with definitions in xine-lib's events.h
    */
   ACTID_EVENT_MENU1         = XINE_EVENT_INPUT_MENU1          | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_MENU2         = XINE_EVENT_INPUT_MENU2          | ACTID_IS_INPUT_EVENT,
@@ -178,7 +192,7 @@ typedef enum {
   ACTID_EVENT_ANGLE_NEXT    = XINE_EVENT_INPUT_ANGLE_NEXT     | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_ANGLE_PRIOR   = XINE_EVENT_INPUT_ANGLE_PREVIOUS | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_SELECT        = XINE_EVENT_INPUT_SELECT         | ACTID_IS_INPUT_EVENT,
-  ACTID_EVENT_NUMBER_0      = XINE_EVENT_INPUT_NUMBER_0       | ACTID_IS_INPUT_EVENT,  
+  ACTID_EVENT_NUMBER_0      = XINE_EVENT_INPUT_NUMBER_0       | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_NUMBER_1      = XINE_EVENT_INPUT_NUMBER_1       | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_NUMBER_2      = XINE_EVENT_INPUT_NUMBER_2       | ACTID_IS_INPUT_EVENT,
   ACTID_EVENT_NUMBER_3      = XINE_EVENT_INPUT_NUMBER_3       | ACTID_IS_INPUT_EVENT,
@@ -239,25 +253,39 @@ typedef enum {
    * End of numeric mapping.
    */
 } action_id_t;
-  
-kbinding_t *kbindings_init_kbinding(void);
-void kbindings_save_kbinding(kbinding_t *);
-void kbindings_reset_kbinding(kbinding_t *);
-void kbindings_free_kbinding(kbinding_t **);
-void kbindings_display_current_bindings(kbinding_t *);
-void kbindings_display_default_lirc_bindings(void);
-void kbindings_display_default_bindings(void);
-kbinding_entry_t *kbindings_lookup_action(kbinding_t *, const char *);
-void kbindings_handle_kbinding(kbinding_t *, XEvent *);
-action_id_t kbindings_get_action_id(kbinding_entry_t *);
-char *kbindings_get_shortcut(kbinding_t *, char *);
 
-void kbedit_window(void);
-void kbedit_end(void);
-int kbedit_is_visible(void);
-int kbedit_is_running(void);
-void kbedit_toggle_visibility(xitk_widget_t *, void *);
-void kbedit_raise_window(void);
-void kbedit_reparent(void);
+kbinding_t *kbindings_init_kbinding (gGui_t *gui, const char *keymap_file);
+
+void kbindings_reset_kbinding (kbinding_t *kbt);
+
+typedef enum {
+  KBT_DISPLAY_MODE_DEFAULT = 1,
+  KBT_DISPLAY_MODE_LIRC,
+  KBT_DISPLAY_MODE_CURRENT,
+  KBT_DISPLAY_MODE_MAN
+} kbedit_display_mode_t;
+
+void kbindings_display_bindings (gGui_t *gui, kbedit_display_mode_t mode);
+
+action_id_t kbinding_aid_from_be_event (kbinding_t *kbt, const xitk_be_event_t *event, int no_gui);
+const kbinding_entry_t *kbindings_lookup_binding (kbinding_t *kbt, const char *key, int modifier);
+const kbinding_entry_t *kbindings_lookup_action (kbinding_t *kbt, const char *action);
+action_id_t kbindings_get_action_id (const kbinding_entry_t *entry);
+
+void kbindings_save_kbinding (gGui_t *gui, kbinding_t *kbt, const char *keymap_file);
+
+void kbindings_free_kbinding (kbinding_t **kbt);
+
+/* return bytes written (without terminating nul).
+ * if result >= buf_size, output was truncated. Does not return space required!
+ * if result == 0, entry was not found.
+ */
+size_t kbindings_get_shortcut (kbinding_t *kbt, const char *action, char *buf, size_t buf_size, int style);
+
+void kbedit_window (gGui_t *gui);
+void kbedit_end (xui_keyedit_t *kbedit);
+int kbedit_is_visible (xui_keyedit_t *kbedit);
+void kbedit_toggle_visibility (xitk_widget_t *w, void *kbedit);
+void kbedit_raise_window (xui_keyedit_t *kbedit);
 
 #endif
