@@ -1,18 +1,18 @@
-/* 
- * Copyright (C) 2000-2019 the xine project
- * 
+/*
+ * Copyright (C) 2000-2021 the xine project
+ *
  * This file is part of xine, a unix video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
@@ -26,51 +26,35 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
 
 #include "common.h"
+#include "mrl_browser.h"
+#include "panel.h"
+#include "playlist.h"
+#include "videowin.h"
+#include "actions.h"
+#include "event.h"
+#include "errors.h"
+#include "xine-toolkit/mrlbrowser.h"
+
+typedef void (*select_cb_t) (xitk_widget_t *w, void *mrlb, int, int);
 
 struct xui_mrlb_st {
   gGui_t *gui;
   xitk_widget_t *w;
 };
 
-/*
- *
- */
-void mrl_browser_show_tips (xui_mrlb_t *mrlb, int enabled, unsigned long timeout) {
-  if (mrlb && mrlb->w)
-    xitk_mrlbrowser_set_tips_timeout (mrlb->w, enabled, timeout);
-}
-
-void mrl_browser_update_tips_timeout (xui_mrlb_t *mrlb, unsigned long timeout) {
-  if (mrlb && mrlb->w) {
-    if (xitk_get_widget_tips_timeout (mrlb->w) > 0)
-      xitk_mrlbrowser_set_tips_timeout (mrlb->w, 1, timeout);
-  }
-}
-
-/*
- *
- */
-void set_mrl_browser_transient (xui_mrlb_t *mrlb) {
-  if (mrlb && mrlb->w) {
-    if (!mrlb->gui->use_root_window && mrlb->gui->video_display == mrlb->gui->display)
-      xitk_mrlbrowser_set_transient (mrlb->w, mrlb->gui->video_window);
-  }
-}
-
 /*
  *
  */
 void mrl_browser_change_skins (xui_mrlb_t *mrlb, int synthetic) {
   (void)synthetic;
   if (mrlb && mrlb->w) {
+    xitk_window_t *xwin = xitk_mrlbrowser_get_window(mrlb->w);
     xitk_mrlbrowser_change_skins (mrlb->w, mrlb->gui->skin_config);
-    set_mrl_browser_transient (mrlb);
+    video_window_set_transient_for(mrlb->gui->vwin, xwin);
     if (mrl_browser_is_visible (mrlb))
-      raise_window ((xitk_mrlbrowser_get_window_id (mrlb->w)), 1, 1);
+      raise_window (mrlb->gui, xwin, 1, 1);
   }
 }
 
@@ -99,8 +83,8 @@ void show_mrl_browser (xui_mrlb_t *mrlb) {
   if (mrlb && mrlb->w) {
     mrlb->gui->nongui_error_msg = NULL;
     xitk_mrlbrowser_show (mrlb->w);
-    set_mrl_browser_transient (mrlb);
-    layer_above_video ((xitk_mrlbrowser_get_window_id (mrlb->w)));
+    video_window_set_transient_for(mrlb->gui->vwin, xitk_mrlbrowser_get_window(mrlb->w));
+    layer_above_video (mrlb->gui, xitk_mrlbrowser_get_window (mrlb->w));
   }
 }
 
@@ -136,14 +120,13 @@ void destroy_mrl_browser (xui_mrlb_t *mrlb) {
       window_info_t wi;
 
       if ((xitk_mrlbrowser_get_window_info (mrlb->w, &wi))) {
-        config_update_num ("gui.mrl_browser_x", wi.x);
-        config_update_num ("gui.mrl_browser_y", wi.y);
+        config_update_num (mrlb->gui->xine, "gui.mrl_browser_x", wi.x);
+        config_update_num (mrlb->gui->xine, "gui.mrl_browser_y", wi.y);
       }
-      xitk_mrlbrowser_destroy (mrlb->w);
-      mrlb->w = NULL;
+      xitk_widgets_delete (&mrlb->w, 1);
     }
     mrlb->gui->mrlb = NULL;
-    try_to_set_input_focus (mrlb->gui->video_window);
+    video_window_set_input_focus (mrlb->gui->vwin);
     free (mrlb);
   }
 }
@@ -162,13 +145,13 @@ static void mrl_browser_kill(xitk_widget_t *w, void *data) {
       window_info_t wi;
 
       if ((xitk_mrlbrowser_get_window_info (mrlb->w, &wi))) {
-        config_update_num ("gui.mrl_browser_x", wi.x);
-        config_update_num ("gui.mrl_browser_y", wi.y);
+        config_update_num (mrlb->gui->xine, "gui.mrl_browser_x", wi.x);
+        config_update_num (mrlb->gui->xine, "gui.mrl_browser_y", wi.y);
       }
       mrlb->w = NULL;
     }
     mrlb->gui->mrlb = NULL;
-    try_to_set_input_focus (mrlb->gui->video_window);
+    video_window_set_input_focus (mrlb->gui->vwin);
     free (mrlb);
   }
 }
@@ -177,8 +160,8 @@ static xitk_mrlbrowser_filter_t **mrl_browser_get_valid_mrl_ending (xui_mrlb_t *
   xitk_mrlbrowser_filter_t **filters = NULL;
   int                        num_endings = 0;
   char                      *mrl_exts, *pmrl_exts, *p, *pp;
-  
-  filters                      = (xitk_mrlbrowser_filter_t **) 
+
+  filters                      = (xitk_mrlbrowser_filter_t **)
     calloc((num_endings + 2), sizeof(xitk_mrlbrowser_filter_t *));
   filters[num_endings]         = (xitk_mrlbrowser_filter_t *)
     xitk_xmalloc(sizeof(xitk_mrlbrowser_filter_t));
@@ -189,39 +172,39 @@ static xitk_mrlbrowser_filter_t **mrl_browser_get_valid_mrl_ending (xui_mrlb_t *
   if(mrl_exts) {
     char  patterns[2048];
     char *e;
-    
+
     p = strdup(mrl_exts);
 
     num_endings++;
-    
+
     pp = p;
     while(*p != '\0') {
       if(*p == ' ')
 	*p = ',';
       p++;
     }
-    
+
     filters[num_endings]         = (xitk_mrlbrowser_filter_t *) xitk_xmalloc(sizeof(xitk_mrlbrowser_filter_t));
     filters[num_endings]->name   = strdup(_("All extensions"));
     filters[num_endings]->ending = pp;
 
     pmrl_exts = mrl_exts;
     while((e = xine_strsep(&pmrl_exts, " ")) != NULL) {
-      
+
       snprintf(patterns, sizeof(patterns), "*.%s", e);
 
       num_endings++;
-      
-      filters                      = (xitk_mrlbrowser_filter_t **) 
+
+      filters                      = (xitk_mrlbrowser_filter_t **)
 	realloc(filters, sizeof(xitk_mrlbrowser_filter_t *) * (num_endings + 2));
-      
+
       filters[num_endings]         = (xitk_mrlbrowser_filter_t *)
 	xitk_xmalloc(sizeof(xitk_mrlbrowser_filter_t));
 
       filters[num_endings]->name   = strdup(patterns);
       filters[num_endings]->ending = strdup(e);
     }
-    
+
     free(mrl_exts);
   }
 
@@ -229,11 +212,16 @@ static xitk_mrlbrowser_filter_t **mrl_browser_get_valid_mrl_ending (xui_mrlb_t *
     xitk_xmalloc(sizeof(xitk_mrlbrowser_filter_t));
   filters[num_endings + 1]->name   = NULL;
   filters[num_endings + 1]->ending = NULL;
-  
+
   return filters;
 }
 
 
+static void mrl_browser_rpwin (void *data, xitk_window_t *xwin) {
+  gGui_t *gui = data;
+  reparent_window (gui, xwin);
+}
+
 /*
  *
  */
@@ -249,7 +237,7 @@ static xui_mrlb_t *mrl_browser (gGui_t *gui,
 
   if (gui->mrlb) {
     show_mrl_browser (gui->mrlb);
-    set_mrl_browser_transient (gui->mrlb);
+    video_window_set_transient_for(gui->vwin, xitk_mrlbrowser_get_window(gui->mrlb->w));
     return gui->mrlb;
   }
 
@@ -261,30 +249,29 @@ static xui_mrlb_t *mrl_browser (gGui_t *gui,
   ip_availables = xine_get_browsable_input_plugin_ids (mrlb->gui->xine);
   mrl_filters = mrl_browser_get_valid_mrl_ending (mrlb);
 
-  XITK_WIDGET_INIT (&mb, mrlb->gui->imlib_data);
+  XITK_WIDGET_INIT (&mb);
 
-  mb.window_trans = (mrlb->gui->use_root_window || mrlb->gui->video_display != mrlb->gui->display) ? None
-                  : mrlb->gui->video_window;
-  mb.layer_above  = (is_layer_above ());
-  mb.icon         = &mrlb->gui->icon;
-  mb.set_wm_window_normal = !video_window_is_visible (mrlb->gui->vwin);
-  mb.x = xine_config_register_num (mrlb->gui->xine, "gui.mrl_browser_x",
-    200, "gui mrl browser x coordinate",
-    CONFIG_NO_HELP, CONFIG_LEVEL_DEB, CONFIG_NO_CB, CONFIG_NO_DATA);
-  mb.y = xine_config_register_num (mrlb->gui->xine, "gui.mrl_browser_y",
-    100, "gui mrl browser y coordinate",
-    CONFIG_NO_HELP, CONFIG_LEVEL_DEB, CONFIG_NO_CB, CONFIG_NO_DATA);
+  mb.reparent_window = mrl_browser_rpwin;
+  mb.rw_data = mrlb->gui;
+  mb.layer_above  = is_layer_above (mrlb->gui);
+  mb.icon         = mrlb->gui->icon;
+
+  mb.x = 200;
+  mb.y = 100;
+  gui_load_window_pos (mrlb->gui, "mrl_browser", &mb.x, &mb.y);
   mb.window_title = _("xine MRL Browser");
 
   mb.skin_element_name        = "MrlBG";
   mb.resource_name            = mb.window_title;
   mb.resource_class           = "xine";
-  
+
   mb.origin.skin_element_name = "MrlCurOrigin";
   mb.origin.cur_origin        = NULL;
 
   mb.dndcallback              = dnd_cb;
-  mb.dnddata                  = gui;
+  mb.dnd_cb_data              = gui;
+  mb.input_cb                 = gui_handle_be_event;
+  mb.input_cb_data            = gui;
 
   mb.select.skin_element_name = "MrlSelect";
   mb.select.caption           = _("Add");
@@ -331,7 +318,9 @@ static xui_mrlb_t *mrl_browser (gGui_t *gui,
 
   mb.mrl_filters                           = mrl_filters;
 
-  mrlb->w = xitk_mrlbrowser_create (NULL, mrlb->gui->skin_config, &mb);
+  mrlb->w = xitk_mrlbrowser_create (mrlb->gui->xitk, mrlb->gui->skin_config, &mb);
+
+  video_window_set_transient_for(mrlb->gui->vwin, xitk_mrlbrowser_get_window(mrlb->w));
 
   if(mrl_filters) {
     int i;
@@ -349,15 +338,6 @@ static xui_mrlb_t *mrl_browser (gGui_t *gui,
   return mrlb;
 }
 
-/*
- *
- */
-static void mrl_handle_selection (xitk_widget_t *w, void *data, int selected) {
-  (void)w;
-  (void)data;
-  (void)selected;
-}
-
 /*
  * Callback called by mrlbrowser on add event.
  */
@@ -367,24 +347,24 @@ static void mrl_add_noautoplay(xitk_widget_t *w, void *data, xine_mrl_t *mrl) {
   (void)w;
   if (mrlb && mrl) {
     int num = mrlb->gui->playlist.num;
-    
-    if(!playlist_is_running()) {
-      playlist_editor();
+
+    if (!mrlb->gui->plwin) {
+      playlist_editor (mrlb->gui);
     }
     else {
-      if(!playlist_is_visible())
-	playlist_toggle_visibility(NULL, NULL);
+      if (!playlist_is_visible (mrlb->gui))
+        playlist_toggle_visibility (mrlb->gui);
     }
-    
-    mediamark_append_entry((char *)mrl->mrl, (char *)mrl->mrl, NULL, 0, -1, 0, 0);
-    
+
+    mediamark_append_entry (mrlb->gui, (char *)mrl->mrl, (char *)mrl->mrl, NULL, 0, -1, 0, 0);
+
     if ((!num) && ((xine_get_status (mrlb->gui->stream) == XINE_STATUS_STOP) || mrlb->gui->logo_mode)) {
       mrlb->gui->playlist.cur = mrlb->gui->playlist.num - 1;
-      gui_set_current_mmk(mediamark_get_current_mmk());
-    }   
-    
-    playlist_update_playlist();
-    
+      gui_set_current_mmk (mrlb->gui, mediamark_get_current_mmk (mrlb->gui));
+    }
+
+    playlist_update_playlist (mrlb->gui);
+
     if ((!is_playback_widgets_enabled (mrlb->gui->panel)) && mrlb->gui->playlist.num)
       enable_playback_controls (mrlb->gui->panel, 1);
   }
@@ -395,16 +375,16 @@ static void mrl_add(xitk_widget_t *w, void *data, xine_mrl_t *mrl) {
 
   (void)w;
   if (mrlb && mrl) {
-    
-    if(!playlist_is_running()) {
-      playlist_editor();
+
+    if (!mrlb->gui->plwin) {
+      playlist_editor (mrlb->gui);
     }
     else {
-      if(!playlist_is_visible())
-	playlist_toggle_visibility(NULL, NULL);
+      if (!playlist_is_visible (mrlb->gui))
+        playlist_toggle_visibility (mrlb->gui);
     }
-    
-    gui_dndcallback((char *)mrl->mrl);
+
+    gui_dndcallback (mrlb->gui, (const char *)mrl->mrl);
   }
 }
 
@@ -418,39 +398,39 @@ static void mrl_play(xitk_widget_t *w, void *data, xine_mrl_t *mrl) {
   if (mrlb && mrl) {
     mediamark_t mmk;
     char        *_mrl = mrl->mrl;
-    
+
     if ((xine_get_status (mrlb->gui->stream) != XINE_STATUS_STOP)) {
       mrlb->gui->ignore_next = 1;
       xine_stop (mrlb->gui->stream);
       mrlb->gui->ignore_next = 0;
     }
-    
+
     if (!is_playback_widgets_enabled (mrlb->gui->panel))
       enable_playback_controls (mrlb->gui->panel, 1);
 
     if(mrl_look_like_playlist(_mrl)) {
-      if(mediamark_concat_mediamarks(_mrl)) {
-	gui_set_current_mmk(mediamark_get_current_mmk());
-	_mrl = (char *) mediamark_get_current_mrl();
-	playlist_update_playlist();
+      if (mediamark_concat_mediamarks (mrlb->gui, _mrl)) {
+        gui_set_current_mmk (mrlb->gui, mediamark_get_current_mmk (mrlb->gui));
+        _mrl = (char *) mediamark_get_current_mrl (mrlb->gui);
+        playlist_update_playlist (mrlb->gui);
       }
     }
-    
-    osd_hide();
+
+    osd_hide (mrlb->gui);
 
     if (!xine_open (mrlb->gui->stream, (const char *) _mrl)) {
-      gui_handle_xine_error (mrlb->gui->stream, _mrl);
+      gui_handle_xine_error (mrlb->gui, mrlb->gui->stream, _mrl);
       enable_playback_controls (mrlb->gui->panel, 0);
-      gui_display_logo();
+      gui_display_logo (mrlb->gui);
       return;
     }
 
     if (!gui_xine_play (mrlb->gui, mrlb->gui->stream, 0, 0, 0)) {
       enable_playback_controls (mrlb->gui->panel, 0);
-      gui_display_logo();
+      gui_display_logo (mrlb->gui);
       return;
     }
-    
+
     mmk.mrl           = _mrl;
     mmk.ident         = NULL;
     mmk.sub           = NULL;
@@ -461,14 +441,10 @@ static void mrl_play(xitk_widget_t *w, void *data, xine_mrl_t *mrl) {
     mmk.got_alternate = 0;
     mmk.alternates    = NULL;
     mmk.cur_alt       = NULL;
-    gui_set_current_mmk(&mmk);
+    gui_set_current_mmk (mrlb->gui, &mmk);
   }
 }
 
-void mrl_browser_reparent (xui_mrlb_t *mrlb) {
-  if (mrlb && mrlb->w)
-    reparent_window ((xitk_mrlbrowser_get_window_id (mrlb->w)));
-}
 
 /*
  * Create a new mrl browser.
@@ -476,19 +452,18 @@ void mrl_browser_reparent (xui_mrlb_t *mrlb) {
 void open_mrlbrowser(xitk_widget_t *w, void *data) {
   gGui_t *gui = data;
 
+  (void)w;
   if (gui) {
-    mrl_browser (gui, mrl_add, mrl_play, mrl_handle_selection, gui_dndcallback);
-    set_mrl_browser_transient (gui->mrlb);
-    mrl_browser_show_tips (gui->mrlb, panel_get_tips_enable (gui->panel), panel_get_tips_timeout (gui->panel));
+    mrl_browser (gui, mrl_add, mrl_play, NULL, gui_dndcallback);
   }
 }
 
 void open_mrlbrowser_from_playlist(xitk_widget_t *w, void *data) {
   gGui_t *gui = data;
 
+  (void)w;
   if (gui) {
-    mrl_browser (gui, mrl_add_noautoplay, mrl_play, mrl_handle_selection, gui_dndcallback);
-    set_mrl_browser_transient (gui->mrlb);
-    mrl_browser_show_tips (gui->mrlb, panel_get_tips_enable (gui->panel), panel_get_tips_timeout (gui->panel));
+    mrl_browser (gui, mrl_add_noautoplay, mrl_play, NULL, gui_dndcallback);
   }
 }
+
