@@ -18,13 +18,17 @@
  * a simple playlist implementataion
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
 #include "common.h"
+#include "../actions.h"
+#include "../playlist.h"
 
 #include "oxine.h"
 #include "otk.h"
@@ -112,7 +116,7 @@ static void changelist (otk_widget_t *list) {
       pretty_name_free = pretty_name = get_basename(gGui->playlist.mmk[i]->mrl);
     else
       pretty_name = gGui->playlist.mmk[i]->ident;
-    
+
     snprintf(tmp, 511, "%s %s",  ( i == gGui->playlist.cur ) ? "->" : "  ", pretty_name);
     otk_add_listentry(list, tmp, NULL, -1);
     free(pretty_name_free);
@@ -123,7 +127,7 @@ static void changelist (otk_widget_t *list) {
 }
 
 static void playlist_play_cb(void *data, void *entry) {
-
+  gGui_t *gui = gGui;
   pl_session_t *session = (pl_session_t*) data;
   oxine_t *oxine = session->oxine;
   int n = otk_list_get_entry_number(session->list) - 1;
@@ -131,11 +135,11 @@ static void playlist_play_cb(void *data, void *entry) {
   session->listpos = otk_list_get_pos(session->list);
 
   if (session->action == PL_ACTION_PLAY) {
-    gGui->playlist.cur = n;
-    gui_set_current_mmk(gGui->playlist.mmk[n]);
+    gui->playlist.cur = n;
+    gui_set_current_mmk (gui, gui->playlist.mmk[n]);
 
-    if( gui_xine_open_and_play(gGui->mmk.mrl, gGui->mmk.sub, 0,
-        gGui->mmk.start, gGui->mmk.av_offset, gGui->mmk.spu_offset, 0) ) {
+    if (gui_xine_open_and_play (gui, gui->mmk.mrl, gui->mmk.sub, 0,
+        gui->mmk.start, gui->mmk.av_offset, gui->mmk.spu_offset, 0) ) {
 
       oxine->main_window = NULL;
       oxine->info_window = NULL;
@@ -145,7 +149,7 @@ static void playlist_play_cb(void *data, void *entry) {
     } /* else play_error(oxine); */
   }
   if (session->action == PL_ACTION_REMOVE) {
-    playlist_delete_entry(n);
+    playlist_delete_entry (gui, n);
     playlist_reentry_cb(session);
   }
 }
@@ -154,7 +158,7 @@ static void playlist_clear_cb (void *data) {
 
   /* pl_session_t *session = (pl_session_t*) data; */
 
-  playlist_delete_all(NULL, NULL);
+  playlist_delete_all (gGui);
 
   playlist_reentry_cb(data);
 }
@@ -165,7 +169,7 @@ static void playlist_leave_cb (void *data) {
 
   session->oxine->reentry = NULL;
   session->oxine->reentry_data = NULL;
-  
+
   session->oxine->main_menu_cb(session->oxine);
 }
 
@@ -197,7 +201,7 @@ static void playlist_reentry_cb (void *data) {
   b = otk_selector_new (oxine->main_window, 10, 80, 195, 60, pl_action_strings, 2, action_changed, session);
   otk_set_focus(b);
   otk_selector_set(b, session->action);
-  
+
   /*
   otk_button_new (oxine->main_window, 10, 150, 195, 60, "load", playlist_load_cb, session);
   otk_button_new (oxine->main_window, 10, 210, 195, 60, "Save", playlist_save_cb, session);
@@ -210,7 +214,7 @@ static void playlist_reentry_cb (void *data) {
   session->list = otk_list_new(list_window, 10, 15, 523, 390, playlist_play_cb, session);
   changelist(session->list);
   otk_list_set_pos(session->list, session->listpos);
-  
+
   otk_draw_all(oxine->otk);
 }
 
