@@ -1,18 +1,18 @@
-/* 
- * Copyright (C) 2000-2014 the xine project
- * 
+/*
+ * Copyright (C) 2000-2021 the xine project
+ *
  * This file is part of xine, a unix video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
@@ -42,6 +42,10 @@
 #include <errno.h>
 
 #include "common.h"
+#include "session.h"
+#include "panel.h"
+#include "playlist.h"
+#include "actions.h"
 #include "session_internal.h"
 
 
@@ -53,11 +57,11 @@ static char         *socket_name;
 
 static int ssend_packet(int fd, const void *data, uint32_t data_length) {
   ctrl_header_packet_t  hdr;
-  
+
   hdr.version     = CTRL_PROTO_VERSION;
   hdr.command     = 0;
   hdr.data_length = data_length;
-  
+
   return _send_packet(fd, data, &hdr);
 }
 
@@ -68,7 +72,7 @@ static void send_ack(serv_header_packet_t *shdr) {
 
 static int send_uint32(int session, ctrl_commands_t command, uint32_t value) {
   int fd;
-  
+
   if((fd = connect_to_session(session)) == -1)
     return -1;
   if (send_packet(fd, command, &value, sizeof(uint32_t)) >= 0) {
@@ -83,10 +87,10 @@ static uint32_t get_uint32(int session, ctrl_commands_t command) {
   ctrl_header_packet_t  hdr;
   void                 *data;
   int                   fd, ret = 0;
-  
+
   if((fd = connect_to_session(session)) == -1)
     return ret;
-  
+
   if (send_packet(fd, command, NULL, 0) < 0) {
     close(fd);
     return 0;
@@ -106,7 +110,7 @@ static uint32_t get_uint32(int session, ctrl_commands_t command) {
 void send_boolean(int session, ctrl_commands_t command, uint8_t value) {
   int     fd;
   uint8_t bvalue = (value > 0) ? 1 : 0;
-  
+
   if((fd = connect_to_session(session)) == -1)
     return;
   send_packet(fd, command, &bvalue, sizeof(uint8_t));
@@ -119,7 +123,7 @@ uint8_t get_boolean(int session, ctrl_commands_t command) {
   uint8_t               ret = 0;
   void                 *data;
   int                   fd;
-  
+
   if((fd = connect_to_session(session)) == -1)
     return ret;
 
@@ -131,12 +135,13 @@ uint8_t get_boolean(int session, ctrl_commands_t command) {
   }
   read_ack(fd);
   close(fd);
-  
+
   return ret;
 }
 #endif
 
 static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
+  gGui_t *gui = data;
   fd_set                set;
   struct timeval        tv;
   serv_header_packet_t *shdr;
@@ -149,7 +154,7 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
 
   while(!going)
     xine_usec_sleep(10000);
-  
+
   while(going) {
     int res;
 
@@ -206,150 +211,150 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
     switch(shdr->hdr.command) {
 
     case CMD_PLAY:
-      gui_play(NULL, NULL);
+      gui_play (NULL, gui);
       send_ack(shdr);
       break;
-      
+
     case CMD_SLOW_2:
-      xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_SLOW_2);
+      xine_set_param (gui->stream, XINE_PARAM_SPEED, XINE_SPEED_SLOW_2);
       send_ack(shdr);
       break;
 
     case CMD_SLOW_4:
-      xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_SLOW_4);
+      xine_set_param (gui->stream, XINE_PARAM_SPEED, XINE_SPEED_SLOW_4);
       send_ack(shdr);
       break;
 
     case CMD_PAUSE:
-      xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE);
+      xine_set_param (gui->stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE);
       send_ack(shdr);
       break;
 
     case CMD_FAST_2:
-      xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_FAST_2);
+      xine_set_param (gui->stream, XINE_PARAM_SPEED, XINE_SPEED_FAST_2);
       send_ack(shdr);
       break;
 
     case CMD_FAST_4:
-      xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_FAST_4);
+      xine_set_param (gui->stream, XINE_PARAM_SPEED, XINE_SPEED_FAST_4);
       send_ack(shdr);
       break;
 
     case CMD_STOP:
-      gui_stop(NULL, NULL);
+      gui_stop (NULL, gui);
       send_ack(shdr);
       break;
 
     case CMD_QUIT:
-      gui_exit(NULL, NULL);
+      gui_exit (NULL, gui);
       send_ack(shdr);
       break;
 
     case CMD_FULLSCREEN:
-      gui_set_fullscreen_mode(NULL, NULL);
+      gui_set_fullscreen_mode (NULL, gui);
       send_ack(shdr);
       break;
 
     case CMD_EJECT:
-      gui_eject(NULL, NULL);
+      gui_eject (NULL, gui);
       send_ack(shdr);
       break;
 
     case CMD_AUDIO_NEXT:
-      gui_change_audio_channel(NULL, (void *) GUI_NEXT);
+      gui_nextprev_audio_channel (NULL, GUI_NEXT (gui));
       send_ack(shdr);
       break;
 
     case CMD_AUDIO_PREV:
-      gui_change_audio_channel(NULL, (void *) GUI_PREV);
+      gui_nextprev_audio_channel (NULL, GUI_PREV (gui));
       send_ack(shdr);
       break;
 
     case CMD_SPU_NEXT:
-      gui_change_spu_channel(NULL, (void *) GUI_NEXT);
+      gui_nextprev_spu_channel (NULL, GUI_NEXT (gui));
       send_ack(shdr);
       break;
 
     case CMD_SPU_PREV:
-      gui_change_spu_channel(NULL, (void *) GUI_PREV);
+      gui_nextprev_spu_channel (NULL, GUI_PREV (gui));
       send_ack(shdr);
       break;
-	
+
     case CMD_PLAYLIST_FIRST:
-      if(gGui->playlist.num) {
-	if(xine_get_status(gGui->stream) == XINE_STATUS_PLAY)
-	  gui_stop(NULL, NULL);
-	
-	gGui->playlist.cur = 0;
-	gui_set_current_mmk(mediamark_get_current_mmk());
-	gui_play(NULL, NULL);
+      if (gui->playlist.num) {
+        if (xine_get_status (gui->stream) == XINE_STATUS_PLAY)
+          gui_stop (NULL, gui);
+
+        gui->playlist.cur = 0;
+        gui_set_current_mmk (gui, mediamark_get_current_mmk (gui));
+        gui_play (NULL, gui);
       }
       send_ack(shdr);
       break;
-      
+
     case CMD_PLAYLIST_LAST:
-      if(gGui->playlist.num) {
-	if(xine_get_status(gGui->stream) == XINE_STATUS_PLAY)
-	  gui_stop(NULL, NULL);
-	
-	gGui->playlist.cur = gGui->playlist.num - 1;
-	gui_set_current_mmk(mediamark_get_current_mmk());
-	gui_play(NULL, NULL);
+      if (gui->playlist.num) {
+        if (xine_get_status (gui->stream) == XINE_STATUS_PLAY)
+          gui_stop (NULL, gui);
+
+        gui->playlist.cur = gui->playlist.num - 1;
+        gui_set_current_mmk (gui, mediamark_get_current_mmk (gui));
+        gui_play (NULL, gui);
       }
       send_ack(shdr);
       break;
 
     case CMD_PLAYLIST_FLUSH:
-      playlist_delete_all(NULL, NULL);
+      playlist_delete_all (gui);
       send_ack(shdr);
       break;
-      
+
     case CMD_PLAYLIST_ADD:
-      gui_dndcallback((char *)shdr->data);
+      gui_dndcallback (gui, (char *)shdr->data);
       send_ack(shdr);
       break;
-      
+
     case CMD_PLAYLIST_NEXT:
-      gui_direct_nextprev(NULL, (void *) GUI_NEXT, 1);
+      gui_step_mrl (gui, 1);
       send_ack(shdr);
       break;
 
     case CMD_PLAYLIST_PREV:
-      gui_direct_nextprev(NULL, (void *) GUI_PREV, 1);
+      gui_step_mrl (gui, -1);
       send_ack(shdr);
       break;
 
     case CMD_PLAYLIST_LOAD:
-      mediamark_load_mediamarks((const char *)shdr->data);
-      gui_set_current_mmk(mediamark_get_current_mmk());
-      playlist_update_playlist();
-      if((!is_playback_widgets_enabled()) && gGui->playlist.num)
-	enable_playback_controls(1);
+        mediamark_load_mediamarks (gui, (const char *)shdr->data);
+      gui_set_current_mmk (gui, mediamark_get_current_mmk (gui));
+      playlist_update_playlist (gui);
+      if ((!is_playback_widgets_enabled (gui->panel)) && gui->playlist.num)
+        enable_playback_controls (gui->panel, 1);
       send_ack(shdr);
       break;
 
     case CMD_PLAYLIST_STOP:
-      if(xine_get_status(gGui->stream) != XINE_STATUS_STOP)
-	gGui->playlist.control |= PLAYLIST_CONTROL_STOP;
+      if(xine_get_status (gui->stream) != XINE_STATUS_STOP)
+        gui->playlist.control |= PLAYLIST_CONTROL_STOP;
       send_ack(shdr);
       break;
 
     case CMD_PLAYLIST_CONTINUE:
-      if(xine_get_status(gGui->stream) != XINE_STATUS_STOP)
-	gGui->playlist.control &= ~PLAYLIST_CONTROL_STOP;
+      if (xine_get_status (gui->stream) != XINE_STATUS_STOP)
+        gui->playlist.control &= ~PLAYLIST_CONTROL_STOP;
       send_ack(shdr);
       break;
 
     case CMD_VOLUME:
       {
 	int *vol = (int *)shdr->data;
-	
-	if((gGui->mixer.method == SOUND_CARD_MIXER) && 
-	   (gGui->mixer.caps & MIXER_CAP_VOL) && ((*vol >= 0) && (*vol <= 100)))
-	  change_audio_vol(*vol);
-	else if((gGui->mixer.method == SOFTWARE_MIXER) && ((*vol >= 0) && (*vol <= 200)))
-	  change_amp_vol(*vol);
-	
+
+        if ((gui->mixer.method == SOUND_CARD_MIXER) &&
+          (gui->mixer.caps & MIXER_CAP_VOL) && ((*vol >= 0) && (*vol <= 100)))
+          gui_set_audio_vol (gui, *vol);
+        else if ((gui->mixer.method == SOFTWARE_MIXER) && ((*vol >= 0) && (*vol <= 200)))
+          gui_set_amp_level (gui, *vol);
+
 	send_ack(shdr);
       }
       break;
@@ -357,14 +362,14 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
     case CMD_AMP:
       {
 	int *amp = (int *)shdr->data;
-	
+
 	if((*amp >= 0) && (*amp <= 200))
-	  change_amp_vol(*amp);
+          gui_set_amp_level (gui, *amp);
 
 	send_ack(shdr);
       }
       break;
-      
+
     case CMD_LOOP:
       {
 	int *loop = (int *)shdr->data;
@@ -376,10 +381,10 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
 	case PLAYLIST_LOOP_SHUFFLE:
 	case PLAYLIST_LOOP_SHUF_PLUS:
 	case PLAYLIST_LOOP_MODES_NUM:
-	  gGui->playlist.loop = *loop;
+          gui->playlist.loop = *loop;
 	  break;
 	}
-	
+
 	send_ack(shdr);
       }
       break;
@@ -388,8 +393,8 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
       {
 	uint32_t status = 2;
 
-	if(xine_get_status(gGui->stream) == XINE_STATUS_PLAY) {
-	  int speed = xine_get_param(gGui->stream, XINE_PARAM_SPEED);
+        if (xine_get_status (gui->stream) == XINE_STATUS_PLAY) {
+          int speed = xine_get_param (gui->stream, XINE_PARAM_SPEED);
 
 	  switch(speed) {
 	  case XINE_SPEED_NORMAL:
@@ -416,16 +421,16 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
 	    break;
 	  }
 	}
-	
+
 	send_packet(shdr->fd, CMD_GET_SPEED_STATUS, &status, sizeof(status));
 	send_ack(shdr);
       }
       break;
-    
+
 
     case CMD_GET_TIME_STATUS_IN_SECS:
       {
-	uint32_t status = gGui->stream_length.time / 1000;
+        uint32_t status = gui->stream_length.time / 1000;
 	send_packet(shdr->fd, CMD_GET_TIME_STATUS_IN_SECS, &status, sizeof(status));
 	send_ack(shdr);
       }
@@ -433,7 +438,7 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
 
     case CMD_GET_TIME_STATUS_IN_POS:
       {
-	uint32_t status = gGui->stream_length.pos;
+        uint32_t status = gui->stream_length.pos;
 	send_packet(shdr->fd, CMD_GET_TIME_STATUS_IN_POS, &status, sizeof(status));
 	send_ack(shdr);
       }
@@ -464,12 +469,12 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
 void deinit_session(void) {
   if(session_id >= 0) {
     struct stat   sstat;
-    
+
     going = 0;
     close(ctrl_fd);
     if(((stat(socket_name, &sstat)) > -1) && (S_ISSOCK(sstat.st_mode)))
       unlink(socket_name);
-    
+
     free(socket_name);
   }
 }
@@ -481,29 +486,33 @@ int init_session(void) {
   } saddr;
   int                  retval = 0;
   int                  i;
-  
+
   if((ctrl_fd = xine_socket_cloexec(AF_UNIX, SOCK_STREAM, 0)) != -1) {
 
     for(i = 0;; i++)	{
       saddr.un.sun_family = AF_UNIX;
-      
-      snprintf(saddr.un.sun_path, 108, "%s%s%d", (xine_get_homedir()), "/.xine/session.", i);
+
+      snprintf(saddr.un.sun_path, sizeof(saddr.un.sun_path), "%s%s%d", (xine_get_homedir()), "/.xine/session.", i);
       if(!is_remote_running(i)) {
 	if((unlink(saddr.un.sun_path) == -1) && errno != ENOENT) {
-	  fprintf(stderr, "setup_ctrlsocket(): Failed to unlink %s (Error: %s)", 
+	  fprintf(stderr, "setup_ctrlsocket(): Failed to unlink %s (Error: %s)",
 		  saddr.un.sun_path, strerror(errno));
 	}
       }
       else
 	continue;
-      
-      if((bind(ctrl_fd, &saddr.sa, sizeof (saddr.un))) != -1) {
 
+#ifdef SUN_LEN
+      if((bind(ctrl_fd, &saddr.sa, SUN_LEN(&saddr.un))) != -1)
+#else
+      if((bind(ctrl_fd, &saddr.sa, sizeof (saddr.un))) != -1)
+#endif
+      {
 	session_id = i;
 	listen(ctrl_fd, 100);
 	going = 1;
-	
-	pthread_create(&thread_server, NULL, ctrlsocket_func, NULL);
+
+        pthread_create (&thread_server, NULL, ctrlsocket_func, gGui);
 	socket_name = strdup(saddr.un.sun_path);
 	retval = 1;
 	break;
@@ -517,7 +526,7 @@ int init_session(void) {
   }
   else
     fprintf(stderr, "setup_ctrlsocket(): Failed to open socket: %s", strerror(errno));
-  
+
   if(!retval) {
     if(ctrl_fd != -1)
       close(ctrl_fd);
@@ -531,7 +540,7 @@ static int sanestrcasecmp(const char *s1, const char *s2) {
   if(s1 && s2)
     return strcasecmp(s1, s2);
   return 1;
-} 
+}
 
 int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session) {
   int          playlist_first, playlist_last, playlist_clear, playlist_next, playlist_prev, playlist_stop_cont;
@@ -551,12 +560,12 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
     /* Don't change order */
     "play",  "slow4",  "slow2",   "pause",      "fast2",
     "fast4", "stop",   "quit",    "fullscreen", "eject",
-    "audio", "spu",    "session", "mrl",        "playlist", 
+    "audio", "spu",    "session", "mrl",        "playlist",
     "pl",    "volume", "amp",     "loop",       "get_speed",
     "get_time",
     NULL
   };
-  
+
   playlist_first = playlist_last = playlist_clear = playlist_next = playlist_prev = playlist_stop_cont = 0;
   audio_next     = audio_prev = spu_next = spu_prev = 0;
   volume = amp   = -1;
@@ -596,17 +605,17 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
       else if(!sanestrcasecmp(optstr, "prev"))
 	spu_prev++;
       break;
-      
+
       /* session */
     case 12:
       if((atoi(optstr)) >= 0)
 	optsess = atoi(optstr);
       break;
-      
+
       /* mrl */
     case 13:
       mrls = (char **) realloc(mrls, sizeof(char *) * (num_mrls + 2));
-      
+
       mrls[num_mrls++] = strdup(optstr);
       mrls[num_mrls]   = NULL;
       break;
@@ -641,7 +650,7 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
     case 17:
       amp = strtol(optstr, &optstr, 10);
       break;
-      
+
       /* loop */
     case 18:
       if(!sanestrcasecmp(optstr, "none"))
@@ -660,7 +669,7 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
     case 19:
       speed_status = 1;
       break;
-      
+
     case 20:
       time_status = 1;
       if(!sanestrcasecmp(optstr, "p") || !sanestrcasecmp(optstr, "pos"))
@@ -675,11 +684,11 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
     mrls[num_mrls++] = strdup(enqueue_mrl);
     mrls[num_mrls]   = NULL;
   }
-  
+
   *session = (optsess >= 0) ? optsess : 0;
-  
+
   if(is_remote_running(*session)) {
-    
+
     if((state << (CMD_QUIT - 1)) & 0x80000000)
       remote_cmd(*session, CMD_QUIT);
 
@@ -695,12 +704,12 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
       remote_cmd(*session, CMD_PLAYLIST_NEXT);
       playlist_next--;
     }
-    
+
     while(playlist_prev) {
       remote_cmd(*session, CMD_PLAYLIST_PREV);
       playlist_prev--;
     }
-    
+
     if(playlist_stop_cont < 0)
       remote_cmd(*session, CMD_PLAYLIST_STOP);
 
@@ -711,9 +720,9 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
       for(i = 0; i < num_mrls; i++)
 	send_string(*session, CMD_PLAYLIST_ADD, mrls[i]);
     }
-    
-    /* 
-     * CMD_PLAY, CMD_SLOW_4, CMD_SLOW_2, CMD_PAUSE, CMD_FAST_2, 
+
+    /*
+     * CMD_PLAY, CMD_SLOW_4, CMD_SLOW_2, CMD_PAUSE, CMD_FAST_2,
      * CMD_FAST_4, CMD_STOP, CMD_FULLSCREEN, CMD_EJECT
      */
     if(state) {
@@ -725,12 +734,12 @@ int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session
 
     while(audio_next) {
       remote_cmd(*session, CMD_AUDIO_NEXT);
-      playlist_next--;
+      audio_next--;
     }
 
     while(audio_prev) {
       remote_cmd(*session, CMD_AUDIO_PREV);
-      playlist_next--;
+      audio_prev--;
     }
 
     while(spu_next) {
