@@ -1,18 +1,18 @@
-/* 
- * Copyright (C) 2000-2017 the xine project
- * 
+/*
+ * Copyright (C) 2000-2020 the xine project
+ *
  * This file is part of xine, a unix video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
@@ -22,6 +22,7 @@
 
 /* required for S_ISSOCK */
 #define _BSD_SOURCE 1
+#define _DEFAULT_SOURCE 1
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -40,6 +41,7 @@
 #include <errno.h>
 
 #include "common.h"
+#include "session.h"
 #include "session_internal.h"
 
 #ifndef S_ISSOCK
@@ -48,25 +50,32 @@
 
 int connect_to_session(int session) {
   int fd;
-  
+
   if((fd = xine_socket_cloexec(AF_UNIX, SOCK_STREAM, 0)) != -1) {
     union {
       struct sockaddr_un un;
       struct sockaddr sa;
     } saddr;
     uid_t                stored_uid, euid;
-    
+
     saddr.un.sun_family = AF_UNIX;
     stored_uid       = getuid();
     euid             = geteuid();
-    setuid(euid);
-
-    snprintf(saddr.un.sun_path, 108, "%s%s%d", (xine_get_homedir()), "/.xine/session.", session);
-    setreuid(stored_uid, euid);
+    if (setuid(euid) == -1)
+      perror("setuid() failed");
 
+    snprintf(saddr.un.sun_path, sizeof(saddr.un.sun_path), "%s%s%d", (xine_get_homedir()), "/.xine/session.", session);
+    if (setreuid(stored_uid, euid) == -1)
+      perror("setreuid() failed");
+#ifdef SUN_LEN
+    if((connect(fd,&saddr.sa, SUN_LEN(&saddr.un))) != -1) {
+      return fd;
+    }
+#else
     if((connect(fd,&saddr.sa, sizeof(saddr.un))) != -1) {
       return fd;
     }
+#endif
 
     close(fd);
   }
@@ -76,7 +85,7 @@ int connect_to_session(int session) {
 
 void *read_packet(int fd, ctrl_header_packet_t *hdr) {
   void *data = NULL;
-  
+
   if((read(fd, hdr, sizeof(ctrl_header_packet_t))) == sizeof(ctrl_header_packet_t)) {
     if(hdr->data_length) {
       data = malloc(hdr->data_length);
@@ -93,7 +102,7 @@ void *read_packet(int fd, ctrl_header_packet_t *hdr) {
 void read_ack(int fd) {
   ctrl_header_packet_t  hdr;
   void                 *data;
-  
+
   data = read_packet(fd, &hdr);
   SAFE_FREE(data);
 }
@@ -149,7 +158,7 @@ int _send_packet(int fd, const void *data, ctrl_header_packet_t *hdr) {
 
 int send_packet(int fd, ctrl_commands_t command, const void *data, uint32_t data_length) {
   ctrl_header_packet_t  hdr;
-  
+
   hdr.version     = CTRL_PROTO_VERSION;
   hdr.command     = command;
   hdr.data_length = data_length;
@@ -159,7 +168,7 @@ int send_packet(int fd, ctrl_commands_t command, const void *data, uint32_t data
 
 int send_string(int session, ctrl_commands_t command, const char *string) {
   int fd;
-  
+
   if((fd = connect_to_session(session)) == -1)
     return -1;
   if (send_packet(fd, command, string, string ? strlen(string) + 1 : 0) < 0) {
@@ -175,7 +184,7 @@ int send_string(int session, ctrl_commands_t command, const char *string) {
 
 static int _remote_cmd(int session, ctrl_commands_t command, int timeout) {
   int fd;
-  
+
   if((fd = connect_to_session(session)) == -1)
     return 0;
 
@@ -191,7 +200,7 @@ static int _remote_cmd(int session, ctrl_commands_t command, int timeout) {
 
   read_ack(fd);
   close(fd);
-  
+
   return 1;
 }
 
